#!/usr/bin/perl
# Copyright (C) 2007-2009 Timesys Corporation
use strict;
use warnings;
use DBI;
use Data::Dumper;

my $dbh     = DBI->connect('dbi:Pg:dbname=;host=', '', '', {AutoCommit => 0})
                or die "Failed to connect to db: $!";
my %attr_map = (
    'FILES'             => 'files',
    'RUNTIME_DEPENDS'   => 'runtime_depends',
    'BUILD_OPTIONS'     => 'build_options',
    'CONFIGURE_OPTIONS' => 'configure_options',
    'DEPENDS'           => 'depends',
    'WORKINGDIR'        => 'working_dir',
    'PATCHES'           => 'patches',
    'SOURCE'            => 'source',
    'VERSION'           => 'version'
);

my $pkg_lookup      = $dbh->prepare('SELECT * FROM unit WHERE name = ? and version = ? ORDER BY ID DESC');
my $attr_lookup     = $dbh->prepare('SELECT * FROM unitattribute WHERE unit_id = ? ORDER BY ID DESC');
my $old_attr_lookup = $dbh->prepare('SELECT * FROM unitattribute WHERE unit_id = (SELECT id FROM unit WHERE name = ? ORDER BY id DESC LIMIT 1)');
my $kernel_lookup   = $dbh->prepare('SELECT u.* FROM unitattribute a INNER JOIN unit u ON a.unit_id = u.id WHERE u.name = \'kernel\' and u.version= ? and a.name = \'board\' and a.value = ?');

my @optional_attrs  = qw(uclibc_incompatible board board_limit_list POPULAR PROVIDES
                         suggests suggests_provider TS_NOT_RECOMMENDED require_full_subscription);
my @template_attrs  = qw(
TSWO_PLATFORM_TEMPLATE_BUSYBOX_INIT TSWO_PLATFORM_TEMPLATE_SYSTEMV_INIT
TSWO_PLATFORM_TEMPLATE_DEBUGGING    TSWO_PLATFORM_TEMPLATE_DEVELOPMENT
TSWO_PLATFORM_TEMPLATE_AUDIO        TSWO_PLATFORM_TEMPLATE_VIDEO
TSWO_PLATFORM_TEMPLATE_GRAPHICS     TSWO_PLATFORM_TEMPLATE_NETWORKING
TSWO_PLATFORM_TEMPLATE_FILESYSTEMS  TSWO_PLATFORM_TEMPLATE_X_WINDOWS
TSWO_PLATFORM_TEMPLATE_FRAMEBUFFER  TSWO_PLATFORM_TEMPLATE_MATCHBOX
TSWO_PLATFORM_TEMPLATE_GPE_DESKTOP  TSWO_PLATFORM_TEMPLATE_ENLIGHTENMENT_DESKTOP
TSWO_PLATFORM_TEMPLATE_QT           TSWO_PLATFORM_TEMPLATE_MOBLIN_DESKTOP);

my $updates_generated;
my $next_unit_id;
sub get_next_seq_val
{
    # don't do this... it will modify the sequence on each run
    #$dbh->selectrow_array("select nextval('unit_id_seq')");
    if (!$next_unit_id) {
        $next_unit_id = $dbh->selectrow_array("select max(id) from unit");
    }
    $next_unit_id++;
    return $next_unit_id;
}

sub generate_inserts
{
    my ($pkg, $revision, $attr_values) = @_;
    my $new_id  = get_next_seq_val();
    my $desc    = `./bin/describe_pkg.sh target/software/*/$pkg/Config.in`;

    chomp($desc);
    $desc =~ s/\n/ /g;

    printf("UPDATE unit SET disabled = true WHERE name = %s;\n", $dbh->quote($pkg));
    printf(
        "INSERT INTO unit (id, name, version, revision, label, description, disabled) VALUES (%d,%s,%s,%s,%s,%s,%s);\n",
        $new_id,
        $dbh->quote($pkg),
        $dbh->quote($attr_values->{version}),
        $revision,
        $dbh->quote($pkg),
        $dbh->quote($desc),
        'false'
    );
    printf("select setval('unit_id_seq', %d);\n", $new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'source', $dbh->quote($attr_values->{source} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'patches', $dbh->quote($attr_values->{patches} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'files', $dbh->quote($attr_values->{files} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'working_dir', $dbh->quote($attr_values->{working_dir} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'basic_make', $dbh->quote($attr_values->{basic_make} || 'n'),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'configure_options', $dbh->quote($attr_values->{configure_options} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'build_options', $dbh->quote($attr_values->{build_options} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'category', $dbh->quote($attr_values->{category} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'installed_size', $dbh->quote($attr_values->{installed_size} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'build_time', $dbh->quote($attr_values->{build_time} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'depends', $dbh->quote($attr_values->{depends} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'runtime_depends', $dbh->quote($attr_values->{runtime_depends} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'license', $dbh->quote($attr_values->{license} || ''),$new_id);
    printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
        'changelog_url', $dbh->quote($attr_values->{changelog_url} || ''),$new_id);

    foreach my $optional_attr (@optional_attrs, @template_attrs) {
      if ($attr_values->{$optional_attr}) {
        printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('%s',%s,%d);\n",
          "$optional_attr", $dbh->quote($attr_values->{$optional_attr} || ''),$new_id);
      }
    }

    printf("UPDATE unitattribute SET value = (SELECT id FROM unit WHERE name = '$pkg' AND disabled = false) WHERE name = 'upgraded_by' AND unit_id IN (SELECT id FROM unit WHERE name = '$pkg' AND disabled = true);\n");
    printf("INSERT INTO unitattribute (name, value, unit_id) SELECT 'upgraded_by',(SELECT id FROM unit WHERE name = '$pkg' AND disabled = false), id FROM unit WHERE id IN (SELECT id FROM unit WHERE name = '$pkg' AND disabled = true) AND id NOT IN (SELECT unit.id FROM unit INNER JOIN unitattribute ON unit.id=unitattribute.unit_id WHERE unit.name = '$pkg' AND unitattribute.name = 'upgraded_by');\n\n");

    $updates_generated = 1;
}



my @pkgs = map { chomp; $_ } `grep -r 'config TSWO_SOFTWARE_' toolchain target | cut -f2 -d: | awk '{print \$2}' | sed -re 's/TSWO_SOFTWARE_//' | sort | uniq`;
open(my $fh,'>','.config') or die $!;
print $fh "TSWO_BOARD_i.MX27=y\n";
print $fh "TSWO_LIBC_UCLIBC=y\n";
foreach my $pkg (@pkgs) {
  print $fh "TSWO_SOFTWARE_$pkg=y\n";
}
system("yes '' | make oldconfig &>/dev/null");
# some specific hacks
system("sed -i -r -e '/gtk-fb_\\w*DEPENDS/s/cairo/cairo-fb/' -e '/gtk-fb_\\w*DEPENDS/s/pango/pango-fb/' -e '/pango-fb_\\w*DEPENDS/s/cairo/cairo-fb/' include/config/tswo-config/auto.conf");

# slurp in our work order
my $kconfig_data;
open(my $k,'<','include/config/tswo-config/auto.conf') or die "Failed to open auto.conf: $!";
{
    local $/;
    $kconfig_data = <$k>;
}
close($k);


# go through all of the packages that have exported data
foreach my $pkg ( @pkgs )
{
    # extract the package meta data
    my @attrs = ($kconfig_data =~ m/TSWO_${pkg}_(.*?)=/g);
    my %attr_values;
    foreach my $attr ( @attrs )
    {
        next unless exists $attr_map{$attr};
        ($attr_values{$attr_map{$attr}}) = ($kconfig_data =~ m/TSWO_${pkg}_${attr}=['"]?(.*?)['"]?\n/);
        $attr_values{$attr_map{$attr}} =~ s/\\//g;
    }
    next unless $attr_values{'version'};

    # find the package Config.in
    my $config_in = `grep -rl 'config TSWO_SOFTWARE_$pkg\\s*\$' toolchain target`;
    chomp($config_in) if $config_in;
    # skip it if we cannot find the Config.in
    next unless ( $config_in && -f $config_in );

    # set category
    $attr_values{category} = (split('/',$config_in))[2];
    $attr_values{category} ||= 'FIXME';
    # toolchain categories
    if ($attr_values{category} eq 'Config.in') {
      $attr_values{category} = 'System';
    }

    # read in Config.in
    my $config_in_data;
    open(my $config_in_fh,'<',$config_in) or die $!;
    {
      local $/;
      $config_in_data = <$config_in_fh>;
    }
    close($config_in_fh);

    # skip broken or deprecated packages
    if ($config_in_data =~ m/TSWO_BROKEN/ig) {
      printf("-- $pkg is broken\n");
      printf("UPDATE unit SET disabled = true WHERE name = %s;\n\n", $dbh->quote($pkg));
      next;
    }
    if ($config_in_data =~ m/TSWO_DEPRECATED/ig) {
      printf("-- $pkg is deprecated\n");
      printf("UPDATE unit SET disabled = true WHERE name = %s;\n\n", $dbh->quote($pkg));
      next;
    }

    # extract license
    if ($config_in_data =~ m/license: (.*)/) {
      $attr_values{'license'} = $1;
    }

    # extract uClibc incompatible marking
    if (($config_in_data =~ m/depends\s*\!TSWO_LIBC_UCLIBC/) || ($config_in_data =~ m/depends\s*TSWO_LIBC_GLIBC/)) {
      $attr_values{'uclibc_incompatible'} = 'yes';
    }

    # extract template associations
    if ($config_in_data =~ m/default y if (TSWO_PLATFORM_TEMPLATE.*)/) {
      my @templates = grep /TSWO_PLATFORM_TEMPLATE/, split(/\s+/, $1);
      $attr_values{$_} = 'yes' foreach @templates;
    }

    # extract board_limit_list
    if ($config_in_data =~ m/depends\s*(TSWO_BOARD_.*)\R/) {
      (my $board_limits = $1) =~ s/TSWO_BOARD_//g;
      my @limit_boards = split(/\s*\|\|\s*/,$board_limits);
      $attr_values{'board_limit_list'} = ' ' . join(' ',@limit_boards) . ' ';
    }

    # look up the package and its attributes in the database.
    my ($existing_unit, $existing_attrs);
    $pkg_lookup->execute($pkg, $attr_values{version});
    $existing_unit = $pkg_lookup->fetchall_arrayref();
    if (@$existing_unit) {
        $attr_lookup->execute($existing_unit->[0][0]);
        $existing_attrs = $attr_lookup->fetchall_arrayref();
    }

    if (!@$existing_unit) {
        # if this version of the package is not already in the units table
        printf("-- new entry for %s-%s\n", $pkg, $attr_values{version});

        # try and fill in old attributes for license build_time installed_size changelog_url 
        $old_attr_lookup->execute($pkg);
        if (my $old_attributes = $old_attr_lookup->fetchall_arrayref()) {
            foreach my $attr_entry ( @$old_attributes ) {
                my $a = $attr_entry->[1];
                next unless grep { m/^$a$/ } (qw(license build_time installed_size changelog_url), @optional_attrs, @template_attrs);
                $attr_values{$a} ||= $attr_entry->[2];
            }
        }

        generate_inserts($pkg, 1, \%attr_values);
        print "\n";
    } else {
        die "Could not find existing attributes for $pkg!" if !@$existing_attrs;

        # look to see if the package attributes have been modified
        my @differs;
        my %prev_attrs;
        foreach my $attr_entry ( @$existing_attrs )
        {
            no warnings;
            my $a = $attr_entry->[1];
            $prev_attrs{$a} = $attr_entry->[2];
            next if ! exists $attr_values{$a};
            if ($attr_entry->[2] ne $attr_values{ $a })
            {
                printf("-- %s %s ('%s' -> '%s')\n",$pkg,$a,$attr_entry->[2],$attr_values{ $a });
                push @differs, $a;
            }
        }

        # check template association
        foreach my $template ( @template_attrs )
        {
          next if
                defined $prev_attrs{$template}
                && defined $attr_values{$template}
                && $prev_attrs{$template} eq $attr_values{$template};
          if (defined $prev_attrs{$template} || defined $attr_values{$template}) {
            my $prev = $prev_attrs{$template} || '';
            my $new  = $attr_values{$template} || '';
            printf("-- %s %s ('%s' -> '%s')\n",$pkg,$template,$prev, $new);
            #if ($existing_unit) {
            #  printf("INSERT INTO unitattribute (name, value, unit_id) values ('%s','%s',%d);\n", $template, 'yes', $existing_unit->[0][0]);
            #}
            push @differs, $template;
          }
        }

        # if the attributes differ, we need to create a new revision 
        if (0 < scalar(@differs)) {
            printf("-- new revision for %s (updated %s)\n",$pkg, join(',',@differs));
            # try and carry over category, installed_size, build_time, license, changelog_url
            foreach my $a ((qw(category installed_size build_time license changelog_url), @optional_attrs))
            {
                if (!$attr_values{$a} && $prev_attrs{$a}) {
                    $attr_values{$a} = $prev_attrs{$a};
                }
            }
            generate_inserts($pkg, $existing_unit->[0][3]+1, \%attr_values);
            print "\n";
        }
    }

}

my %seen_kernels;
my $toolchain_units = {};
my @boards = map { chomp; $_ } `grep 'config TSWO_BOARD_' target/Config.in.arch | awk '{print \$2}' | grep -v TSWO_BOARD_NONE | sed -re 's/TSWO_BOARD_//'`;
my @libcs = qw(glibc uClibc);
foreach my $board (@boards) {
  foreach my $libc (@libcs) {
    # setup work order
    open(my $wo,'>','.config') or die "Failed to open .config for writnig: $!";
    printf $wo "TSWO_BOARD_%s=y\n", $board;
    printf $wo "TSWO_LIBC_%s=y\n", uc($libc);
    close($wo);
    system("yes '' | make oldconfig &>/dev/null");

    # read default versions
    open(my $conf,'<','include/config/tswo-config/auto.conf') or die "Failed to open auto.conf for reading: $!";
    my $conf_data;
    {
      local $/;
      $conf_data = <$conf>;
    }
    close($conf);
    my ($arch) = ($conf_data =~ m/TSWO_ARCH=\"(.*?)\"/);

    # kernel
    if ($conf_data =~ m/TSWO_kernel_VERSION=\"(.*?)\"/) {
      my $kernel_version = $1;
      if ($conf_data =~ m/TSWO_KERNEL_CONFIG=\"(.*?)\"/) {
        (my $kernel_config = $1) =~ s/^file:\/\/\$\(BASE_DIR\)\///;
        $kernel_config =~ s/\$\(TSWO_kernel_VERSION\)/$kernel_version/;
        $kernel_config =~ s/\$\(TSWO_ARCH\)/$arch/;

        my $board_label = `sed -n "/^config TSWO_BOARD_$board/,/^\\s*bool/p" target/Config.in.arch | sed -re '/^config TSWO_BOARD_/d' -e 's/^\\s*bool\\s*\\"(.*?)\\".*\$/\\1/'`;
        chomp($board_label);

        # skip malta kernels
        if ($board =~ m/malta/) {
          $seen_kernels{$board . '_' . $kernel_version} = 1;
        }

        $kernel_lookup->execute($kernel_version, $board);
        my $existing_kernel = $kernel_lookup->fetchall_arrayref();
        if (!@$existing_kernel && !$seen_kernels{$board . '_' . $kernel_version}) {
          my $new_id  = get_next_seq_val();
          printf("-- new $board_label $kernel_version Kernel\n");
          printf("INSERT INTO unit (name, version, revision, label, description) VALUES ('kernel','$kernel_version','1','$kernel_version Kernel','$kernel_version Kernel for the $board_label');\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('serial','yes',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('networking_ethernet','yes',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('category','System',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('license','GPL',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('board','$board',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('installed_size','1785740',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('build_time','631',(SELECT MAX(id) FROM unit));\n");
          printf("INSERT INTO kernelconfig (config) VALUES (\n");
          open(my $fh,'<',$kernel_config) or die "Failed to open $kernel_config: $!";
          my $kernel_config_data;
          {
            local $/;
            $kernel_config_data = <$fh>;
          }
          printf("%s\n", $dbh->quote($kernel_config_data));
          close($fh);
          printf(");\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('config',(SELECT MAX(id) FROM kernelconfig),(SELECT MAX(id) FROM unit));\n\n");
        }
        $seen_kernels{$board . '_' . $kernel_version} = 1;
      }
    };

    foreach my $component (qw(binutils gcc gdb glibc uClibc)) {
      if ($conf_data =~ m/TSWO_${component}_VERSION=\"(.*?)\"/) {
        my $version = $1;
        $toolchain_units->{$component}->{$version}->{$board} = 1;
      }
    }
  }
}

foreach my $unit (keys %$toolchain_units) {
  my @versions = keys %{$toolchain_units->{$unit}};
  foreach my $version (@versions) {
    my @supported_boards = keys %{$toolchain_units->{$unit}->{$version}};

    $pkg_lookup->execute($unit, $version);
    my $existing_unit = $pkg_lookup->fetchall_arrayref();
    if (!@$existing_unit) {
      # add the unit
      my $new_id  = get_next_seq_val();
      printf("-- new $unit - $version\n");
      printf(
        "INSERT INTO unit (id, name, version, revision, label, description, disabled) VALUES (%d,%s,%s,%s,%s,%s,%s);\n",
        $new_id,
        $dbh->quote($unit),
        $dbh->quote($version),
        '1',
        $dbh->quote($unit),
        '',
        'false'
      );
      printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('build_time','',$new_id);\n");
      printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('installed_size','',$new_id);\n");
      printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('category','Development',$new_id);\n");
      printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('license','',$new_id);\n");
      printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('basic_make','y',$new_id);\n");
      foreach my $board ( @supported_boards ) {
        printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('TS_RECOMMENDED_FOR_$board','yes',$new_id);\n");
      }
    } else {
      my $unit_id = $existing_unit->[0][0];
      $attr_lookup->execute($unit_id);
      my $existing_attrs = $attr_lookup->fetchall_arrayref();
      # check board recommendations
      foreach my $board ( @supported_boards ) {
        if ( ! grep { $_->[1] eq "TS_RECOMMENDED_FOR_$board" } @$existing_attrs ) {
          printf("-- Recommend $unit - $version for $board\n");
          printf("INSERT INTO unitattribute (name, value, unit_id) VALUES ('TS_RECOMMENDED_FOR_$board','yes',$unit_id);\n");
        }
      }
    }
    printf("\n");
  }
}


if ($updates_generated)
{
    print ("-- carry over recommends, popular, and provides\n");
    print ("INSERT INTO unitattribute (name, value, unit_id) SELECT a2.name, a2.value, CAST(a.value AS int) FROM unit AS u INNER JOIN unitattribute AS a ON u.id = a.unit_id AND a.name = 'upgraded_by' INNER JOIN unitattribute AS a2 ON u.id = a2.unit_id AND a2.name LIKE '%RECOMMEND%' WHERE CAST(a.value AS int) NOT IN (SELECT unit.id FROM unit INNER JOIN unitattribute ON unit.id = unitattribute.unit_id WHERE unit.id = CAST(a.value AS int) AND unitattribute.name LIKE '%RECOMMEND%') GROUP BY a.value,a2.name,a2.value;\n");
    print ("INSERT INTO unitattribute (name, value, unit_id) SELECT a2.name, a2.value, CAST(a.value AS int) FROM unit AS u INNER JOIN unitattribute AS a ON u.id = a.unit_id AND a.name = 'upgraded_by' INNER JOIN unitattribute AS a2 ON u.id = a2.unit_id AND a2.name LIKE '%POPULAR%' WHERE CAST(a.value AS int) NOT IN (SELECT unit.id FROM unit INNER JOIN unitattribute ON unit.id = unitattribute.unit_id WHERE unit.id = CAST(a.value AS int) AND unitattribute.name LIKE '%POPULAR%') GROUP BY a.value,a2.name,a2.value;\n");
    print ("INSERT INTO unitattribute (name, value, unit_id) SELECT a2.name, a2.value, CAST(a.value AS int) FROM unit AS u INNER JOIN unitattribute AS a ON u.id = a.unit_id AND a.name = 'upgraded_by' INNER JOIN unitattribute AS a2 ON u.id = a2.unit_id AND a2.name LIKE '%PROVIDES%' WHERE CAST(a.value AS int) NOT IN (SELECT unit.id FROM unit INNER JOIN unitattribute ON unit.id = unitattribute.unit_id WHERE unit.id = CAST(a.value AS int) AND unitattribute.name LIKE '%PROVIDES%') GROUP BY a.value,a2.name,a2.value;\n");

}

print ("-- make sure size and build time are not null\n");
print ("UPDATE unitattribute SET value = '0' WHERE name = 'installed_size' AND (value IS NULL OR value = '');\n");
print ("UPDATE unitattribute SET value = '0' WHERE name = 'build_time' AND (value IS NULL OR value = '');\n");

$dbh->rollback();
