#!/bin/bash

FILE=$1

if [ ! -f "$FILE" ]; then
  echo "Usage: $0 [FILE]"
  exit 1
fi

VENDOR=$(grep TSWO_VENDOR_STRING= $FILE | cut -f2 -d\" | sed -re "s/\-$//")
OS=$(grep TSWO_OS_NAME= $FILE | cut -f2 -d\")
BOARD=$(grep TSWO_BOARD= $FILE | cut -f2 -d\")
ARCH=$(grep TSWO_ARCH= $FILE | cut -f2 -d\")
LIBC=$(grep TSWO_TARGET_LIBC= $FILE | cut -f2 -d\")
TARGET="$ARCH-$VENDOR-$OS-$LIBC"
BUILD=build_$TARGET

if [ ! -d $BUILD ]; then
  exit 1
else
  BUILD=$(echo $BUILD)
  echo "|------------------------------------------------------------------------------|"
  printf "| %-20s " "Build Directory"
  printf "| %-53s |\n" $BUILD
fi


KERNEL=images/*mage-*
if [ -f $BUILD/$KERNEL ]; then
  echo "|------------------------------------------------------------------------------|"
  KERNEL=$(echo $BUILD/$KERNEL | sed -e "s|$BUILD\/||")
  printf "| %-20s " "Kernel"
  printf "| %-53s |\n" $KERNEL
fi

TOOLCHAIN=toolchain-final*tgz
if [ -f $BUILD/$TOOLCHAIN ]; then
  echo "|------------------------------------------------------------------------------|"
  TOOLCHAIN=$(echo $BUILD/$TOOLCHAIN | sed -e "s|$BUILD\/||")
  printf "| %-20s " "Toolchain"
  printf "| %-53s |\n" ${TOOLCHAIN:0:53}
fi

TOOLCHAIN_BARE=toolchain-initial*tgz
if [ -f $BUILD/$TOOLCHAIN_BARE ]; then
  echo "|------------------------------------------------------------------------------|"
  TOOLCHAIN_BARE=$(echo $BUILD/$TOOLCHAIN_BARE | sed -e "s|$BUILD\/||")
  printf "| %-20s " "Bare Toolchain"
  printf "| %-53s |\n" ${TOOLCHAIN_BARE:0:53}
fi

if [ -d $BUILD/images/bootloader ]; then
  echo "|------------------------------------------------------------------------------|"
  for file in $(ls $BUILD/images/bootloader/)
  do
    printf "| %-20s " "Bootloader"
    printf "| %-53s |\n" "images/bootloader/$(basename $file)"
  done
fi

if [ -d $BUILD/packages ]; then
  echo "|------------------------------------------------------------------------------|"
  PKG_COUNT=$(ls $BUILD/packages |wc -l)
  printf "| %-20s " "Package Count"
  printf "| %-53s |\n" $PKG_COUNT

  printf "| %-20s " "Package Directory"
  printf "| %-53s |\n" "packages/"
fi

if [ -d $BUILD/images/rfs ]; then
  echo "|------------------------------------------------------------------------------|"
  for file in $(ls $BUILD/images/rfs/)
  do
    printf "| %-20s " "RFS Image"
    printf "| %-53s |\n" "images/rfs/$(basename $file)"
  done
fi

if [ -f $BUILD/*${BOARD}-development-environment.sh ]; then
  echo "|------------------------------------------------------------------------------|"
  SDK=$(echo $BUILD/*${BOARD}-development-environment.sh | sed -r "s|$BUILD\/||")
  printf "| %-20s " "SDK"
  printf "| %-53s |\n" $SDK
fi

echo "|------------------------------------------------------------------------------|"
