# Copyright (C) 2007-2009 Timesys Corporation

LIBC=$(strip $(call UNQUOTE_VAR,$(TSWO_LIBC)))

TSWO_FAKE_INSTALL_DIR=$(BUILD_DIR)/fake
BUILD_PATH=$(TSWO_FAKE_INSTALL_DIR)/bin:$(TSWO_HOST_INSTALL_DIR)/ccache:$(TSWO_HOST_INSTALL_DIR)/bin:$(TSWO_HOST_INSTALL_DIR)/usr/bin:$(TSWO_HOST_INSTALL_DIR)/sbin:$(TSWO_HOST_INSTALL_DIR)/usr/sbin:$(PATH)
TARGET_PATH=$(TSWO_RFS_INSTALL_DIR)/bin:$(TSWO_RFS_INSTALL_DIR)/usr/bin
TARGET_CROSS_PREFIX=$(TSWO_HOST_INSTALL_DIR)/bin/$(TSWO_FULL_TARGET_NAME)-
PACKAGE_DIR=$(BUILD_DIR)/packages
IMAGES_DIR=$(BUILD_DIR)/images
TARGET_ALIASES=CC=$(TSWO_FULL_TARGET_NAME)-gcc AR=$(TSWO_FULL_TARGET_NAME)-ar LD=$(TSWO_FULL_TARGET_NAME)-ld NM=$(TSWO_FULL_TARGET_NAME)-nm AS=$(TSWO_FULL_TARGET_NAME)-as RANLIB=$(TSWO_FULL_TARGET_NAME)-ranlib STRIP=$(TSWO_FULL_TARGET_NAME)-strip CXX=$(TSWO_FULL_TARGET_NAME)-g++ PKG_CONFIG=$(TSWO_HOST_INSTALL_DIR)/bin/pkg-config

# XXX including -I and -L for host paths seems to cause linking issues when building certain apps
#TARGET_CFLAGS=$(call UNQUOTE_VAR,$(TSWO_TARGET_CFLAGS)) -I$(TSWO_HOST_INSTALL_DIR)/include
#TARGET_LDFLAGS=-L$(TSWO_HOST_INSTALL_DIR)/lib $(call UNQUOTE_VAR,$(TSWO_TARGET_LDFLAGS))
TARGET_CFLAGS=$(strip $(call UNQUOTE_VAR,$(TSWO_TARGET_CFLAGS)))
TARGET_CXXFLAGS=$(strip $(call UNQUOTE_VAR,$(TSWO_TARGET_CXXFLAGS)))
TARGET_LDFLAGS=$(strip $(call UNQUOTE_VAR,$(TSWO_TARGET_LDFLAGS)))
TARGET_BUILD_OPTIONS=CFLAGS="$(TARGET_CFLAGS)" LDFLAGS="$(strip $(TARGET_LDFLAGS))" CXXFLAGS="$(strip $(TARGET_CXXFLAGS))" $(call UNQUOTE_VAR,$(TSWO_TARGET_BUILD_OPTIONS))
TARGET_CONFIGURE_OPTIONS=$(call UNQUOTE_VAR,$(TSWO_TARGET_CONFIGURE_OPTIONS))
KERNEL_ARCH=$(strip $(call UNQUOTE_VAR,$(TSWO_KERNEL_ARCH)))
RPM_ARCH=$(strip $(call UNQUOTE_VAR,$(TSWO_RPM_ARCH)))
DEB_ARCH=$(strip $(call UNQUOTE_VAR,$(TSWO_DEB_ARCH)))
HOST_CFLAGS=$(call UNQUOTE_VAR,$(TSWO_HOST_CFLAGS))
HOST_LDFLAGS=$(call UNQUOTE_VAR,$(TSWO_HOST_LDFLAGS))
HOST_BUILD_OPTIONS=CFLAGS="$(HOST_CFLAGS)" LDFLAGS="$(strip $(HOST_LDFLAGS))" $(call UNQUOTE_VAR,$(TSWO_HOST_BUILD_OPTIONS))
HOST_CONFIGURE_OPTIONS=$(call UNQUOTE_VAR,$(TSWO_HOST_CONFIGURE_OPTIONS))

FAKEROOT_CMD=
FAKEROOT_HOST_INSTALL_TARGET=
ifeq (y,$(strip $(TSWO_HOSTTOOL_fakeroot)))
ifneq (y,$(strip $(TSWO_HOST_cygwin)))
FAKEROOT_CMD=fakeroot --
FAKEROOT_HOST_INSTALL_TARGET=fakeroot-host-install
endif
endif

# Add definition for QMAKE
QMAKE=$(TSWO_HOST_INSTALL_DIR)/bin/qmake -spec $(TSWO_HOST_INSTALL_DIR)/usr/share/mkspecs/qws/linux-timesys-g++
# Add definition for cmake
CMAKE=$(TSWO_FAKE_INSTALL_DIR)/bin/cmake cmake -DTSWO_HOST_INSTALL_DIR=$(TSWO_HOST_INSTALL_DIR) -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_TOOLCHAIN_FILE=$(TSWO_HOST_INSTALL_DIR)/toolchain.cmake

COMMA=,
EMPTY:=
SPACE=$(EMPTY) $(EMPTY)

INFLATE.bz2 = $(BZCAT)
INFLATE.gz  = $(ZCAT)
INFLATE.tbz = $(BZCAT)
INFLATE.tgz = $(ZCAT)
INFLATE.xz  = $(XZCAT)
INFLATE.tar = cat

# generic binary tarball package creation macro
define CREATE_TGZ
	cd $(1) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) /bin/bash -c "if [ -f $(1)/.pkg.sh ]; then \
				/bin/bash $(1)/.pkg.sh; rm $(1)/.pkg.sh; fi; $(TAR) czf $(2) ."

endef

define CREATE_RPM
	PATH=$(BUILD_PATH) \
	$(FAKEROOT_CMD) /bin/bash -c "if [ -f $(2)/.pkg.sh ]; then /bin/bash $(2)/.pkg.sh; rm $(2)/.pkg.sh;fi; \
		rpmbuild -bb --clean --rmsource --target=$(RPM_ARCH) \
		--define='_topdir $(BASE_DIR)' \
		--define='_sourcedir $(BASE_DIR)' \
		--define='_tmppath $(BASE_DIR)' \
		--define='_rpmdir $(BASE_DIR)' \
		--define='_builddir $(BASE_DIR)' \
		--define '_ts_pkg_deps $(5)' \
		--define '_ts_pkg_name $(1)' \
		--define '_ts_pkg_ver $(subst -,_,$(3))' \
		--define '_ts_pkg_build_num $(4)' \
		--define '__strip $(TARGET_CROSS_PREFIX)strip' \
		--define '__objdump $(TARGET_CROSS_PREFIX)objdump' \
		--define '_build_name_fmt %{NAME}-%{VERSION}-%{RELEASE}.$(RPM_ARCH)-$(LIBC).rpm' \
		--define '__spec_install_pre %{nil}' \
		--buildroot=$(2) target/software/.package.spec"
	-mv -f $(BASE_DIR)/*.rpm $(6)/
	-rm -rf $(BASE_DIR)/{BUILDROOT,SPECS,SRPMS}
	-rm -rf $(RPM_ARCH)

endef

define CREATE_DEB
	mkdir -p DEBIAN && cp target/software/.package.control DEBIAN/control
	$(SED) -i -r -e "s/PACKAGENAME/$(1)/g" \
		-e "s/PACKAGEVERSION/$(subst -,_,$(3))/g" \
		-e "s/PACKAGEREVISION/$(4)/g" \
		-e "s/PACKAGEDEPENDS/$(subst $(SPACE),$(COMMA),$(5))/g" \
		DEBIAN/control
	(cd DEBIAN && PATH=$(BUILD_PATH) $(FAKEROOT_CMD) $(TAR) czf ../control.tar.gz .)
	(cd $(2) && PATH=$(BUILD_PATH) $(FAKEROOT_CMD) /bin/bash -c "if [ -f $(2)/.pkg.sh ]; then /bin/bash $(2)/.pkg.sh; rm $(2)/.pkg.sh; fi; $(TAR) czf $(BASE_DIR)/data.tar.gz .")
	echo 2.0 > debian-binary
	PATH=$(BUILD_PATH) $(FAKEROOT_CMD) $(TARGET_CROSS_PREFIX)ar -rc $(1)-$(subst -,_,$(3))-$(4)-$(DEB_ARCH)-$(LIBC).deb \
		debian-binary control.tar.gz data.tar.gz 2>&1 >/dev/null
	mv $(1)-$(subst -,_,$(3))-$(4)-$(DEB_ARCH)-$(LIBC).deb $(6)/
	rm -rf DEBIAN debian-binary control.tar.gz data.tar.gz

endef

define CREATE_IPK
	mkdir -p CONTROL && cp target/software/.package.control CONTROL/control
	$(SED) -i -r -e "s/PACKAGENAME/$(1)/g" \
		-e "s/PACKAGEVERSION/$(subst -,_,$(3))/g" \
		-e "s/PACKAGEREVISION/$(4)/g" \
		-e "s/PACKAGEDEPENDS/$(subst $(SPACE),$(COMMA),$(5))/g" \
		CONTROL/control
	(cd CONTROL && PATH=$(BUILD_PATH) $(FAKEROOT_CMD) $(TAR) czf ../control.tar.gz .)
	(cd $(2) && PATH=$(BUILD_PATH) $(FAKEROOT_CMD) /bin/bash -c "if [ -f $(2)/.pkg.sh ]; then /bin/bash $(2)/.pkg.sh; rm $(2)/.pkg.sh; fi; $(TAR) czf $(BASE_DIR)/data.tar.gz .")
	echo 2.0 > debian-binary
	PATH=$(BUILD_PATH) $(FAKEROOT_CMD) tar -czf $(1)-$(subst -,_,$(3))-$(4)-$(DEB_ARCH)-$(LIBC).ipk \
		debian-binary control.tar.gz data.tar.gz 2>&1 >/dev/null
	mv $(1)-$(subst -,_,$(3))-$(4)-$(DEB_ARCH)-$(LIBC).ipk $(6)/
	rm -rf CONTROL debian-binary control.tar.gz data.tar.gz

endef

ifeq (y,$(strip $(TSWO_PACKAGE_AS_RPM)))
CREATE_PACKAGE=$(call CREATE_RPM,$(1),$(2),$(4),$(5),$(6),$(dir $(3)))
else
ifeq (y,$(strip $(TSWO_PACKAGE_AS_DEB)))
CREATE_PACKAGE=$(call CREATE_DEB,$(1),$(2),$(4),$(5),$(6),$(dir $(3)))
else
ifeq (y,$(strip $(TSWO_PACKAGE_AS_IPK)))
CREATE_PACKAGE=$(call CREATE_IPK,$(1),$(2),$(4),$(5),$(6),$(dir $(3)))
else
CREATE_PACKAGE=$(call CREATE_TGZ,$(2),$(3))
endif
endif
endif

# generic fetch macro
define FETCH_REMOTE
	@mkdir -p $(1) && \
	  cd $(1) && \
		$(GET_UTIL) $(BASE_DIR) $(2) $(1)

endef

# generic patch macro
define APPLY_PATCH
	cd $(1) && \
		patch $(ENV_PATCH_OPTIONS) -p1 -i $(2)

endef

# print macros for standard formatting
define PRINT_INFO
	$(info -- $(1) -- $(shell date +%s) [$(shell date -R)])
endef
define PRINT_WARNING
	$(warning -- $(1) -- $(shell date +%s) [$(shell date -R)])
endef
define PRINT_ERROR
	$(error -- $(1) -- $(shell date +%s) [$(shell date -R)])
endef

define UNQUOTE_VAR
	$(patsubst "%,%,$(patsubst %",%,$(1)))
endef

# Reset the libtool archive files (.la) for relative libdir path
define FIX_LIBTOOL_ARCHIVES
	@if [ -d $(1)/lib ]; then  \
		cd $(1)/lib && for la in $$(find . -name '*.la');do \
			subdir=$$(dirname $$la | sed -re 's,\.,,g'); \
			sed -i -re "s,^libdir.*,libdir='$(1)/lib$${subdir}'," \
			-e "s,(\-[RLI])/usr,\1$(1),g" \
			-e "s, /usr/, $(1)/,g" $$la; \
		done; \
	fi
	@if [ -d $(1)/$(TSWO_FULL_TARGET_NAME)/lib ]; then \
		cd $(1)/$(TSWO_FULL_TARGET_NAME)/lib/ && for la in $$(find . -name '*.la');do \
			subdir=$$(dirname $$la | sed -re 's,\.,,g'); \
			sed -i -re "s,^libdir.*,libdir='$(1)/$(TSWO_FULL_TARGET_NAME)/lib$${subdir}'," \
			-e "s,(\-[RLI])/usr,\1$(1),g" \
			-e "s, /usr/, $(1)/,g" $$la; \
		done; \
	fi
endef
# Reset -config scripts for relative path
define FIX_CONFIG_SCRIPTS
	@for config in $$(find $(1) -name '*-config');do \
		sed -i -re "s,=/usr,=$(1),g" \
		-e "s,=\"/usr,=\"$(1),g" \
		-e "s, /usr/, $(1)/,g" \
		-e "s,(\-[RLI])/usr,\1$(1),g" \
		$$config;done
	@for pc in $$(find $(1)/lib/pkgconfig $(1)/usr/lib/pkgconfig $(1)/share/pkgconfig $(1)/usr/share/pkgconfig -name '*.pc' 2>/dev/null);do \
		sed -i -re "s,=/usr,=$(1),g" \
		-e "s,=\"/usr,=\"$(1),g" \
		-e "s,(\-[RLI])/usr,\1$(1),g" \
		$$pc;done
endef

define FIX_QT_MKSPECS
	@for spec in $$(find $(2)/$(1) -name "*.prf" -or -name "*.conf" 2>/dev/null); do \
		sed -i -e "s,\$$\$$\[QT_INSTALL_HEADERS\],$(2)/usr/include,g" \
		-e "s,\$$\$$\[QT_INSTALL_LIBS\],$(2)/usr/lib,g" \
		-e "s,\$$\$$\[QT_INSTALL_BINS\],$(2)/usr/bin,g" \
		$$spec; done
endef

define COMMON_SETUP
$(call MAP_CONFIG_VARS_TO_MK_VARS,$(1))
$(call CREATE_COMMON_DEFINITIONS,$(1),$(2))
endef



# Our package automation macros.  We create wildcard targets
# that are used by all packages that do not define their own.
# The file stamp targets contain the actual definitions.  The
# alias -(action) targets are used by the top level make.
#
# (PKG) is defined for each by the aliasing further below.  This
# always maps the the current package name.
# 
# (PKG)_DIR maps to the (BUILD_DIR)/(PKG)-((PKG)_VERSION) directory. 
# This directory has the .stamp files along with the source directory.
# 
# (PKG)_DDIR maps to the uncompressed package source directory.
# 
# See target/software/.template.
# 

$(BASE_DIR)/.config:
	@touch $@

$(SRC_DL_DIR)/%:
	$(call PRINT_INFO,fetching $(PKG) $($(PKG)_VERSION))
	@mkdir -p $(@D) $($(PKG)_SRC_DL_DIR)
	$(call FETCH_REMOTE,$($(PKG)_SRC_DL_DIR),$($(PKG)_SOURCE_URL))
	$(foreach patch,$($(PKG)_PATCHES),$(call FETCH_REMOTE,$($(PKG)_SRC_DL_DIR),$($(PKG)_URL)/$(patch)))
	$(foreach file,$($(PKG)_FILES),$(call FETCH_REMOTE,$($(PKG)_SRC_DL_DIR),$($(PKG)_URL)/$(file)))

$(BUILD_DIR)/%/.stamp_unpacked: $(SRC_DL_DIR)/%
	$(call PRINT_INFO,unpacking $(PKG) $($(PKG)_VERSION))
	@mkdir -p $(@D)
	@$(INFLATE$(suffix $($(PKG)_SOURCE))) $($(PKG)_SRC_DL_DIR)/$($(PKG)_SOURCE) | \
		$(TAR) -C $(@D) $(TSWO_TAR_OPTIONS) -
	@touch $@


$(BUILD_DIR)/%/.stamp_patched: $(BUILD_DIR)/%/.stamp_unpacked
	$(call PRINT_INFO,patching $(PKG) $($(PKG)_VERSION))
	$(foreach patch,$($(PKG)_PATCHES),$(call APPLY_PATCH,$($(PKG)_DDIR),$($(PKG)_SRC_DL_DIR)/$(patch)))
	@touch $@

$(BUILD_DIR)/%/.stamp_pre_configured: $(BUILD_DIR)/%/.stamp_patched
	@touch $@

# XXX this was the manual way to get the newest config.{guess,sub} into
# the src dir... but now we just call CONFIG_UPDATE and assume that
# doesn't break anything
#$(foreach dir,$($(PKG)_UPDATE_CONFIG),$(call CONFIG_UPDATE,$(dir)))
# XXX not sure if the config-cache is a good idea (or maybe a shared cache across all pkgs?)
#--config-cache
$(BUILD_DIR)/%/.stamp_configured: $(BUILD_DIR)/%/.stamp_pre_configured
	$(call PRINT_INFO,configuring $(PKG) $($(PKG)_VERSION))
	$(call CONFIG_UPDATE,$($(PKG)_DDIR))
	cd $($(PKG)_DDIR) && \
		find . -name ltmain.sh -exec $(SED) -i.orig -re '/add_dir="-L\$$libdir"/d' {} \;
	cd $($(PKG)_DDIR) && rm -rf config.cache 2>/dev/null && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
        $($(PKG)_BUILD_OPTIONS) \
		./configure \
			--target=$(TSWO_FULL_TARGET_NAME) \
			--host=$(TSWO_FULL_TARGET_NAME) \
			--build=$(TSWO_BUILD_NAME) \
        	--prefix=/usr \
        	--exec-prefix=/usr \
			--bindir=/usr/bin \
			--sbindir=/usr/sbin \
			--libdir=/usr/lib \
			--libexecdir=/usr/lib \
			--sysconfdir=/etc \
			--datadir=/usr/share \
			--localstatedir=/var \
			--mandir=/usr/share/man \
			--infodir=/usr/share/info \
			--includedir=/usr/include \
			$(TARGET_CONFIGURE_OPTIONS) \
        	$($(PKG)_CONFIGURE_OPTIONS)
	@touch $@

$(BUILD_DIR)/%/.stamp_post_configured: $(BUILD_DIR)/%/.stamp_configured
	@touch $@

$(BUILD_DIR)/%/.stamp_pre_built: $(BUILD_DIR)/%/.stamp_post_configured
	@touch $@

$(BUILD_DIR)/%/.stamp_built: $(BUILD_DIR)/%/.stamp_pre_built
	$(call PRINT_INFO,building $(PKG) $($(PKG)_VERSION))
	cd $($(PKG)_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
        $($(PKG)_BUILD_OPTIONS) \
		$($(PKG)_MAKE_CMD)
	@touch $@

$(BUILD_DIR)/%/.stamp_post_built: $(BUILD_DIR)/%/.stamp_built
	@touch $@

$(BUILD_DIR)/%/.stamp_checked: $(BUILD_DIR)/%/.stamp_post_built
	$(call PRINT_INFO,checking $(PKG) $($(PKG)_VERSION))
	cd $($(PKG)_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $($(PKG)_BUILD_OPTIONS) \
		$($(PKG)_MAKE_CMD) check
	@touch $@

$(BUILD_DIR)/%/.stamp_pre_rfs_installed: $(BUILD_DIR)/%/.stamp_post_built
	@touch $@

$(BUILD_DIR)/%/.stamp_rfs_installed: $(BUILD_DIR)/%/.stamp_pre_rfs_installed
	$(call PRINT_INFO,installing $(PKG) $($(PKG)_VERSION) to the RFS)
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)
	cd $($(PKG)_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $($(PKG)_BUILD_OPTIONS) \
			$(FAKEROOT_CMD) $($(PKG)_MAKE_CMD) DESTDIR=$(TSWO_RFS_INSTALL_DIR) install
	@touch $@

$(BUILD_DIR)/%/.stamp_post_rfs_installed: $(BUILD_DIR)/%/.stamp_rfs_installed
	@touch $@

$(BUILD_DIR)/%/.stamp_pre_host_installed: $(BUILD_DIR)/%/.stamp_post_built
	@touch $@

$(BUILD_DIR)/%/.stamp_host_installed: $(BUILD_DIR)/%/.stamp_pre_host_installed
	$(call PRINT_INFO,installing $(PKG) $($(PKG)_VERSION) to host)
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)
	cd $($(PKG)_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $($(PKG)_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $($(PKG)_MAKE_CMD) DESTDIR=$(TSWO_HOST_INSTALL_DIR) install
	$(call FIX_LIBTOOL_ARCHIVES,$(TSWO_HOST_INSTALL_DIR))
	$(call FIX_CONFIG_SCRIPTS,$(TSWO_HOST_INSTALL_DIR))
	@touch $@

$(BUILD_DIR)/%/.stamp_post_host_installed: $(BUILD_DIR)/%/.stamp_host_installed
	@touch $@

$(BUILD_DIR)/%/.stamp_pre_packaged: $(BUILD_DIR)/%/.stamp_post_built
	$(call PRINT_INFO,packaging $(PKG) $($(PKG)_VERSION))
	@mkdir -p $($(PKG)_PKG_INSTALL_DIR)
	@touch $@

# XXX need to think about handling package relocations
#$(call FIX_LIBTOOL_ARCHIVES,$($(PKG)_PKG_INSTALL_DIR))
$(BUILD_DIR)/%/.stamp_packaged: $(BUILD_DIR)/%/.stamp_pre_packaged
	cd $($(PKG)_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $($(PKG)_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $($(PKG)_MAKE_CMD) DESTDIR=$($(PKG)_PKG_INSTALL_DIR) install
	@touch $@

$(BUILD_DIR)/%/.stamp_post_packaged: $(BUILD_DIR)/%/.stamp_packaged
	$(call CREATE_PACKAGE, $(PKG),$($(PKG)_PKG_INSTALL_DIR),$($(PKG)_PKG_NAME),$($(PKG)_VERSION),$($(PKG)_BUILDNUM),$($(PKG)_RUNTIME_DEPENDS))
	@rm -rf $($(PKG)_PKG_INSTALL_DIR)
	@touch $@

$(BUILD_DIR)/%/.stamp_cleaned:
	$(call PRINT_INFO,cleaning $(PKG) $($(PKG)_VERSION))
	-cd $($(PKG)_DDIR) && \
		$($(PKG)_MAKE_CMD) clean
	-cd $($(PKG)_DIR) && \
		rm -f .stamp_{*built,*rfs_installed,*host_installed,*packaged}

$(BUILD_DIR)/%/.stamp_distcleaned:
	$(call PRINT_INFO,distcleaning $(PKG) $($(PKG)_VERSION))
ifeq (,$($(PKG)_EXTERNAL_SRC))
	@rm -rf $($(PKG)_SRC_DL_DIR)
endif
	@rm -rf $($(PKG)_PKG_NAME)
	@rm -rf $($(PKG)_DIR)



# this strips the quotes from the config variables
# for use in the makefiles.
define MAP_CONFIG_VARS_TO_MK_VARS
$(1)_VERSION=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_VERSION)))
$(1)_URL=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_URL)))
$(1)_SOURCE=$(subst ",,$(TSWO_$(1)_SOURCE))
#") for syntax highlighting
$(1)_CONFIGURE_OPTIONS=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_CONFIGURE_OPTIONS)))
$(1)_BUILD_OPTIONS=$(subst \,,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_BUILD_OPTIONS))))
$(1)_PATCHES=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_PATCHES)))
$(1)_FILES=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_FILES)))
$(1)_DEPENDS=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_DEPENDS)))
$(1)_RUNTIME_DEPENDS=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_RUNTIME_DEPENDS)))
$(1)_BASIC_MAKE=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_BASIC_MAKE)))
endef


define CREATE_COMMON_DEFINITIONS


# common definitions

$(1)_SOURCE_URL=$$($(1)_URL)/$$($(1)_SOURCE)
$(1)_DIR=$$(BUILD_DIR)/$(1)-$$($(1)_VERSION)
ifneq (,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_WORKINGDIR))))
$(1)_WORKINGDIR=$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_WORKINGDIR)))
else
$(1)_WORKINGDIR=$(1)-$$($(1)_VERSION)
endif
ifneq (,$$($(1)_EXTERNAL_SRC))
$(1)_DDIR=$$($(1)_EXTERNAL_SRC)
else
$(1)_DDIR=$$($(1)_DIR)/$$($(1)_WORKINGDIR)
endif
$(1)_SRC_DL_DIR=$$(SRC_DL_DIR)/$(call FIRST_CHAR,$(1))/$(1)/$(1)-$$($(1)_VERSION)
$(1)_DL_SRC=$$($(1)_SRC_DL_DIR)/$$($(1)_SOURCE)
$(1)_PKG_INSTALL_DIR=$$(PACKAGE_DIR)/$(1)_install
$(1)_BUILDNUM?=1
$(1)_PKG_NAME=$$(PACKAGE_DIR)/$(1)-$$($(1)_VERSION)-$$(TSWO_FULL_TARGET_NAME)-$$($(1)_BUILDNUM).tgz

ifeq (y,$$($(1)_BASIC_MAKE))
$(1)_MAKE_CMD=$(BASIC_MAKE)
else
$(1)_MAKE_CMD=$(MAKE)
endif

# if installing to rfs, we need the dependencies in the host
# and rfs locations.  Otherwise, we just need them in the
# host location to build correctly
$(1)_HOST_INSTALL_DEPS	= $(foreach dep,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_DEPENDS))),$(dep)-host-install)
$(1)_PACKAGE_DEPS		= $(foreach dep,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_DEPENDS))) $(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_RUNTIME_DEPENDS))),$(dep)-package)
ifeq ($(strip $(TSWO_INSTALL_TOOLCHAIN_TO_TARGET)),y)
$(1)_RFS_INSTALL_DEPS	= $(foreach dep,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_DEPENDS))) $(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_RUNTIME_DEPENDS))),$(dep)-rfs-install)
else
$(1)_RFS_INSTALL_DEPS	= $(foreach dep,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_RUNTIME_DEPENDS))),$(dep)-rfs-install)
endif

ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_$(1)_AUTO_HOST_INSTALL))))
$(1)_RFS_INSTALL_DEPS+=$(1)-host-install
$(1)_PACKAGE_DEPS+=$(1)-host-install
endif

# our common, generated targets
$(1)_FETCH_TARGET 				= $$($(1)_DL_SRC)
$(1)_UNPACK_TARGET 				= $$($(1)_DIR)/.stamp_unpacked
$(1)_PATCH_TARGET 				= $$($(1)_DIR)/.stamp_patched
$(1)_PRE_CONFIGURE_TARGET 		= $$($(1)_DIR)/.stamp_pre_configured
$(1)_CONFIGURE_TARGET 			= $$($(1)_DIR)/.stamp_configured
$(1)_POST_CONFIGURE_TARGET 		= $$($(1)_DIR)/.stamp_post_configured
$(1)_PRE_BUILD_TARGET 			= $$($(1)_DIR)/.stamp_pre_built
$(1)_BUILD_TARGET 				= $$($(1)_DIR)/.stamp_built
$(1)_POST_BUILD_TARGET 			= $$($(1)_DIR)/.stamp_post_built
$(1)_CHECK_TARGET 				= $$($(1)_DIR)/.stamp_checked
$(1)_PRE_RFS_INSTALL_TARGET 	= $$($(1)_DIR)/.stamp_pre_rfs_installed
$(1)_RFS_INSTALL_TARGET 		= $$($(1)_DIR)/.stamp_rfs_installed
$(1)_POST_RFS_INSTALL_TARGET 	= $$($(1)_DIR)/.stamp_post_rfs_installed
$(1)_PRE_HOST_INSTALL_TARGET	= $$($(1)_DIR)/.stamp_pre_host_installed
$(1)_HOST_INSTALL_TARGET		= $$($(1)_DIR)/.stamp_host_installed
$(1)_POST_HOST_INSTALL_TARGET	= $$($(1)_DIR)/.stamp_post_host_installed
$(1)_PRE_PACKAGE_TARGET 		= $$($(1)_DIR)/.stamp_pre_packaged
$(1)_PACKAGE_TARGET 			= $$($(1)_DIR)/.stamp_packaged
$(1)_POST_PACKAGE_TARGET 		= $$($(1)_DIR)/.stamp_post_packaged
$(1)_CLEAN_TARGET 				= $$($(1)_DIR)/.stamp_cleaned
$(1)_DISTCLEAN_TARGET 			= $$($(1)_DIR)/.stamp_distcleaned

# our proper targets, with dependent targets added
.PHONY: $(1)-fetch $(1)-unpack $(1)-configure $(1)-build $(1)-check $(1)-rfs-install $(1)-host-install $(1)-package $(1)-clean $(1)-distclean $(1)
ifneq (,$$($(1)_EXTERNAL_SRC))
# fetch, unpack, patch do nothing on external
$(1)-fetch:
$(1)-unpack:
$(1)-patch:
$$($(1)_UNPACK_TARGET) $$($(1)_PATCH_TARGET): $$($(1)_DIR)
	@touch $$@
$$($(1)_DIR):
	mkdir -p $$@
else
$(1)-fetch:			$$($(1)_FETCH_TARGET)
$(1)-unpack:		$(1)-fetch $$($(1)_UNPACK_TARGET)
$(1)-patch:			$(1)-unpack $$($(1)_PATCH_TARGET)
endif
$(1)-configure:		$$($(1)_HOST_INSTALL_DEPS) $(1)-patch $$($(1)_POST_CONFIGURE_TARGET)
$(1)-build:			$(1)-configure $$($(1)_POST_BUILD_TARGET)
# nothing depends on check as it is optional
$(1)-check:			$(1)-build $$($(1)_CHECK_TARGET)
$(1)-rfs-install:	$$($(1)_RFS_INSTALL_DEPS) $(1)-build $$($(1)_POST_RFS_INSTALL_TARGET)
$(1)-host-install:	$(1)-build $$($(1)_POST_HOST_INSTALL_TARGET)
$(1)-package:		$(FAKEROOT_HOST_INSTALL_TARGET) $$($(1)_PACKAGE_DEPS) $(1)-build $$($(1)_POST_PACKAGE_TARGET)
$(1)-clean:			$$($(1)_CLEAN_TARGET)
$(1)-distclean:		$$($(1)_DISTCLEAN_TARGET)
# the default package target installs to the host location and creates a package
$(1):				$(1)-host-install $(1)-package

ifneq (,$$($(1)_EXTERNAL_SRC))
EXTERNAL_CLEAN_TARGETS += $(1)-clean
EXTERNAL_DISTCLEAN_TARGETS += $(1)-distclean
endif

# set our pre and post dependencies
$$($(1)_CONFIGURE_TARGET):		$$($(1)_PRE_CONFIGURE_TARGET)
$$($(1)_BUILD_TARGET):			$$($(1)_PRE_BUILD_TARGET)
$$($(1)_RFS_INSTALL_TARGET):	$$($(1)_PRE_RFS_INSTALL_TARGET)
$$($(1)_HOST_INSTALL_TARGET):	$$($(1)_PRE_HOST_INSTALL_TARGET)
$$($(1)_PACKAGE_TARGET):		$$($(1)_PRE_PACKAGE_TARGET)
$$($(1)_POST_CONFIGURE_TARGET):		$$($(1)_CONFIGURE_TARGET)
$$($(1)_POST_BUILD_TARGET):			$$($(1)_BUILD_TARGET)
$$($(1)_POST_RFS_INSTALL_TARGET):	$$($(1)_RFS_INSTALL_TARGET)
$$($(1)_POST_HOST_INSTALL_TARGET):	$$($(1)_HOST_INSTALL_TARGET)
$$($(1)_POST_PACKAGE_TARGET):		$$($(1)_PACKAGE_TARGET)

# define PKG for these targets
$$($(1)_FETCH_TARGET):				PKG=$(1)
$$($(1)_UNPACK_TARGET):				PKG=$(1)
$$($(1)_PATCH_TARGET):				PKG=$(1)
$$($(1)_PRE_CONFIGURE_TARGET):		PKG=$(1)
$$($(1)_CONFIGURE_TARGET):			PKG=$(1)
$$($(1)_POST_CONFIGURE_TARGET):		PKG=$(1)
$$($(1)_PRE_BUILD_TARGET):			PKG=$(1)
$$($(1)_BUILD_TARGET):				PKG=$(1)
$$($(1)_POST_BUILD_TARGET):			PKG=$(1)
$$($(1)_CHECK_TARGET):				PKG=$(1)
$$($(1)_PRE_RFS_INSTALL_TARGET):	PKG=$(1)
$$($(1)_RFS_INSTALL_TARGET):		PKG=$(1)
$$($(1)_POST_RFS_INSTALL_TARGET):	PKG=$(1)
$$($(1)_PRE_HOST_INSTALL_TARGET):	PKG=$(1)
$$($(1)_HOST_INSTALL_TARGET):		PKG=$(1)
$$($(1)_POST_HOST_INSTALL_TARGET):	PKG=$(1)
$$($(1)_PRE_PACKAGE_TARGET):		PKG=$(1)
$$($(1)_PACKAGE_TARGET):			PKG=$(1)
$$($(1)_POST_PACKAGE_TARGET):		PKG=$(1)
$$($(1)_CLEAN_TARGET):				PKG=$(1)
$$($(1)_DISTCLEAN_TARGET):			PKG=$(1)
%-fetch: 		PKG=$(1)
%-unpack: 		PKG=$(1)
%-patch: 		PKG=$(1)
%-configure:	PKG=$(1)
%-build: 		PKG=$(1)
%-check: 		PKG=$(1)
%-rfs-install: 	PKG=$(1)
%-host-install:	PKG=$(1)
%-package: 		PKG=$(1)
%-clean: 		PKG=$(1)
%-distclean: 	PKG=$(1)


endef

define CUSTOM_SETUP

$$(if $$($(1)_EXTERNAL_SRC),,$$(error Must set $(1)_EXTERNAL_SRC before calling $$$$(call CUSTOM_SETUP,$(1))))
$$(if $$($(1)_VERSION),,$$(error Must set $(1)_VERSION before calling $$$$(call CUSTOM_SETUP,$(1))))

TSWO_$(1)_VERSION=$$($(1)_VERSION)

$(call CREATE_COMMON_DEFINITIONS,$(1)) 

endef

# Borrowed from "GNU Make Standard Library"
tr = $(strip $(eval word := $3)                          \
     $(foreach c,                                                         \
         $(join $(addsuffix :,$1),$2),                                    \
         $(eval word :=                                               \
             $(subst $(word 1,$(subst :, ,$c)),$(word 2,$(subst :, ,$c)), \
                 $(word))))$(word))
[A-Z] := A B C D E F G H I J K L M N O P Q R S T U V W X Y Z #
[a-z] := a b c d e f g h i j k l m n o p q r s t u v w x y z #
[0-9] := 0 1 2 3 4 5 6 7 8 9 #
[A-F] := A B C D E F #
uc = $(call tr,$([a-z]),$([A-Z]),$1)
lc = $(call tr,$([A-Z]),$([a-z]),$1)

FIRST_CHAR = $(call lc,$(filter-out $(1), $(foreach char, a b c d e f g h i j k l m n o p q r s t u v w x y z A B C D E F G H I J K L M N O P Q R S T U V W X Y Z, $(patsubst $(char)%, $(char), $(1)))))


# vim:set noexpandtab: 
