# Copyright (C) 2007-2010 Timesys Corporation
# omap35x-graphics-sdk rules

TSWO_omap35x-graphics-sdk_SOURCE=.stamp_fetched
omap35x-graphics-sdk_INSTALL_DIR=$(strip $(call UNQUOTE_VAR,$(TSWO_omap35x-graphics-sdk_INSTALL_DIR)))

# if Mesa is enabled, sdk must be installed last, it overwrites some libs
ifeq (y,$(TSWO_SOFTWARE_Mesa))
omap35x-graphics-sdk-rfs-install: Mesa-rfs-install
endif

# Define common macros for omap35x-graphics-sdk from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,omap35x-graphics-sdk))


# same as the default, with SOURCE_URL removed
$(omap35x-graphics-sdk_SRC_DL_DIR)/.stamp_fetched:
	$(call PRINT_INFO,fetching omap35x-graphics-sdk $(omap35x-graphics-sdk_VERSION))
	@mkdir -p $(@D) $(omap35x-graphics-sdk_SRC_DL_DIR)
#	$(call FETCH_REMOTE,$(omap35x-graphics-sdk_SRC_DL_DIR),$(omap35x-graphics-sdk_SOURCE_URL))
	$(foreach patch,$(omap35x-graphics-sdk_PATCHES),$(call FETCH_REMOTE,$(omap35x-graphics-sdk_SRC_DL_DIR),$(omap35x-graphics-sdk_URL)/$(patch)))
	$(foreach file,$(omap35x-graphics-sdk_FILES),$(call FETCH_REMOTE,$(omap35x-graphics-sdk_SRC_DL_DIR),$(omap35x-graphics-sdk_URL)/$(file)))
	@touch $@


$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_unpacked:
	@mkdir -p $(@D)
	@if [ ! -d $(TSWO_omap35x-graphics-sdk_INSTALL_DIR) ]; then \
	  echo "Cannot find OMAP35x Graphics SDK in location:" ;\
	  echo "$(TSWO_omap35x-graphics-sdk_INSTALL_DIR)" ;\
	  echo "You must download the SDK from TI and install it before building this package." ;\
	  exit 1; \
	fi
	@touch $@

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_patched:
	@touch $@

omap35x-graphics-sdk-patch: $(omap35x-graphics-sdk_INSTALL_DIR)/.stamp_patched
$(omap35x-graphics-sdk_INSTALL_DIR)/.stamp_patched:
	$(call PRINT_INFO,patching omap35x-graphics-sdk $(omap35x-graphics-sdk_VERSION))
	# apply patches from the config
	$(foreach patch,$(omap35x-graphics-sdk_PATCHES),$(call APPLY_PATCH,$(omap35x-graphics-sdk_INSTALL_DIR),$(omap35x-graphics-sdk_SRC_DL_DIR)/$(patch)))
	@touch $@

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_configured:
	@touch $@

# The build and install scripts that comes with the SDK are kind of a mess
# so we pretty much re-implement them ourselves here.

ifeq ("3.x",$(TSWO_omap35x-graphics-sdk_SILICON_REV))
ifeq (y,$(TSWO_omap35x-graphics-sdk_DEBUG))
omap35x-graphics-sdk_LIBDIR=$(omap35x-graphics-sdk_INSTALL_DIR)/gfx_dbg
else
omap35x-graphics-sdk_LIBDIR=$(omap35x-graphics-sdk_INSTALL_DIR)/gfx_rel
endif
else ifeq ("2.x",$(TSWO_omap35x-graphics-sdk_SILICON_REV))
ifeq (y,$(TSWO_omap35x-graphics-sdk_DEBUG))
omap35x-graphics-sdk_LIBDIR=$(omap35x-graphics-sdk_INSTALL_DIR)/gfx_dbg_es2.x
else
omap35x-graphics-sdk_LIBDIR=$(omap35x-graphics-sdk_INSTALL_DIR)/gfx_rel_es2.x
endif
endif

ifeq (y,$(TSWO_omap35x-graphics-sdk_DEBUG))
omap35x-graphics-sdk_KMOD_DEBUG="BUILD=debug"
endif
ifeq (y,$(TSWO_omap35x-graphics-sdk_DEMOS_X11))
omap35x-graphics-sdk_DEMO_TYPE="X11BUILD=1"
omap35x-graphics-sdk_DEMO_OUT=ReleaseX11
else
omap35x-graphics-sdk_DEMO_OUT=ReleaseRaw
endif

omap35x-graphics-sdk_DEMO_DIRS=$(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_SDK/OGLES*/SDKPackage/Demos/*

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_built:
	$(call PRINT_INFO,building kernel module for omap35x-graphics-sdk $(omap35x-graphics-sdk_VERSION))
	cd $(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_KM && \
		PATH=$(BUILD_PATH) \
		ARCH=$(TSWO_KERNEL_ARCH) \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- \
        	$(omap35x-graphics-sdk_BUILD_OPTIONS) \
		$(omap35x-graphics-sdk_MAKE_CMD) \
		$(omap35x-graphics-sdk_KMOD_DEBUG) \
		KERNELDIR=$(kernel_WORKINGDIR)
ifeq (y,$(TSWO_omap35x-graphics-sdk_DEMOS))
	for demo in $(omap35x-graphics-sdk_DEMO_DIRS)/OGLES*/Build/LinuxGeneric; do \
	  PATH=$(BUILD_PATH) \
          $(omap35x-graphics-sdk_BUILD_OPTIONS) \
	  $(TARGET_ALIASES) \
	  PLATFORM=LinuxOMAP3 \
	  LIBDIR=$(omap35x-graphics-sdk_LIBDIR) \
	  make -C $${demo} $(omap35x-graphics-sdk_DEMO_TYPE) || exit 1 ; \
	done
endif
	@touch $@

define dev-file-install
	# install appropriate libs in /usr/lib
	@mkdir -p $(INSTALL_DIR)/usr/lib/
	for lib in libGLES_CM.so libGLESv2.so libglslcompiler.so \
		libOpenVG.so libOpenVGU.so libIMGegl.so \
		libEGL.so libpvr2d.so libsrv_um.so libPVRScopeServices.so \
		libpvrPVR2D_X11WSEGL.so libpvrPVR2D_BLITWSEGL.so \
		libpvrPVR2D_FLIPWSEGL.so libpvrPVR2D_FRONTWSEGL.so \
	; do \
		cp -f $(omap35x-graphics-sdk_LIBDIR)/$${lib} $(INSTALL_DIR)/usr/lib/$${lib}.$(omap35x-graphics-sdk_VERSION) ; \
		rm -f ${INSTALL_DIR}/usr/lib/$${lib} ; \
		ln -s $${lib}.$(omap35x-graphics-sdk_VERSION) $(INSTALL_DIR)/usr/lib/$${lib} ; \
	done
	# install OGLES and OGLES2 headers
	@mkdir -p $(INSTALL_DIR)/usr/include
	cp -rf $(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_SDK/OGLES*/SDKPackage/Builds/OGLES*/Include/{EGL,GLES,GLES2} $(INSTALL_DIR)/usr/include/
	cp -rf $(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_SDK/OGLES2/SDKPackage/Builds/OGLES2/LinuxOMAP3/Include/GLES $(INSTALL_DIR)/usr/include/
	cp -rf $(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_SDK/OVG/SDKPackage/Builds/OVG/Include/vg/ $(INSTALL_DIR)/usr/include/
	cp -rf $(omap35x-graphics-sdk_INSTALL_DIR)/include/*.h $(INSTALL_DIR)/usr/include/ 
endef

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_rfs_installed: INSTALL_DIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_packaged: INSTALL_DIR=$(omap35x-graphics-sdk_PKG_INSTALL_DIR)
$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_host_installed: INSTALL_DIR=$(TSWO_HOST_INSTALL_DIR)

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_rfs_installed $(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_packaged:
	$(call PRINT_INFO,installing omap35x-graphics-sdk $(omap35x-graphics-sdk_VERSION) to the RFS)
	# install kernel modules
	cd $(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_KM && \
		PATH=$(BUILD_PATH) \
		ARCH=$(TSWO_KERNEL_ARCH) \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- \
		$(omap35x-graphics-sdk_MAKE_CMD) \
		$(omap35x-graphics-sdk_KMOD_DEBUG) \
		KERNELDIR=$(kernel_WORKINGDIR) \
		INSTALL_MOD_PATH=$(INSTALL_DIR) \
		install
	@rm -f $(TSWO_RFS_INSTALL_DIR)/lib/modules/*/source
	@rm -f $(TSWO_RFS_INSTALL_DIR)/lib/modules/*/build
	# headers and libs
	$(dev-file-install)
	# install utilities in /usr/bin
	@mkdir -p $(INSTALL_DIR)/usr/bin/
	for utility in pvrsrvinit \
		sgx_init_test gles2test1 glsltest1_vertshader.txt \
		glsltest1_fragshaderA.txt glsltest1_fragshaderB.txt \
		gles2_texture_stream gles1test1 gles1_texture_stream \
		ovg_unit_test services_test sgx_blit_test sgx_flip_test \
		sgx_render_flip_test sgx_render_test pvr2d_test eglinfo \
		xgles1test1 xmultiegltest \
	; do \
		cp -f $(omap35x-graphics-sdk_LIBDIR)/$${utility} $(INSTALL_DIR)/usr/bin/ ; \
	done
	# install startup script
	@mkdir -p $(INSTALL_DIR)/etc/init.d/
	cp -f $(omap35x-graphics-sdk_LIBDIR)/rc.pvr $(INSTALL_DIR)/etc/init.d/S50-omap35x-graphics-sdk
	sed -i 's|/usr/local/bin|/usr/bin|g' $(INSTALL_DIR)/etc/init.d/S50-omap35x-graphics-sdk
ifeq (y,$(TSWO_omap35x-graphics-sdk_DEMOS))
	# install demos
	@mkdir -p $(INSTALL_DIR)/usr/gfxsdkdemos/
	@mkdir -p $(INSTALL_DIR)/usr/share/applications/
	for demo in $(omap35x-graphics-sdk_DEMO_DIRS); do \
	  exe=$${demo}/OGLES*/Build/LinuxOMAP3/$(omap35x-graphics-sdk_DEMO_OUT)/OGLES*$$(basename $${demo}) ; \
	  cp -f $${exe} $(INSTALL_DIR)/usr/gfxsdkdemos/ || exit 1 ; \
          [ "y" = "$(TSWO_omap35x-graphics-sdk_DEMOS_X11)" ] &&  \
	  echo -e "[Desktop Entry]\n" \
		"Name=$$(basename $${demo})\n" \
		"Type=Application\n" \
		"Exec=/usr/gfxsdkdemos/$$(basename $${exe})\n" \
	      > $(INSTALL_DIR)/usr/share/applications/$$(basename $${exe}).desktop ; \
	  true ; \
	done
	cp -f $(omap35x-graphics-sdk_DEMO_DIRS)/OGLES*/*.{pod,POD,pvr} $(INSTALL_DIR)/usr/gfxsdkdemos/
endif
	echo '[default]' 																> $(INSTALL_DIR)/etc/powervr.ini
ifeq (y,$(TSWO_SOFTWARE_qt-embedded-linux))
	echo 'WindowSystem=libpvrQWSWSEGL.so' 					>> $(INSTALL_DIR)/etc/powervr.ini
	echo '#WindowSystem=libpvrPVR2D_FRONTWSEGL.so' 	>> $(INSTALL_DIR)/etc/powervr.ini
else
	echo '#WindowSystem=libpvrQWSWSEGL.so' 					>> $(INSTALL_DIR)/etc/powervr.ini
	echo 'WindowSystem=libpvrPVR2D_FRONTWSEGL.so' 	>> $(INSTALL_DIR)/etc/powervr.ini
endif
	echo '#WindowSystem=libpvrPVR2D_X11WSEGL.so' 		>> $(INSTALL_DIR)/etc/powervr.ini
	echo '#WindowSystem=libpvrPVR2D_FLIPWSEGL.so' 	>> $(INSTALL_DIR)/etc/powervr.ini
	echo '#WindowSystem=libpvrPVR2D_BLITWSEGL.so' 	>> $(INSTALL_DIR)/etc/powervr.ini


	@touch $@

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing omap35x-graphics-sdk $(omap35x-graphics-sdk_VERSION) to host)
	$(dev-file-install)
	@touch $@

# Don't include depfiles in package, that would conflict with kernel modules
# package.  User will have to run depmod after installing this package. 
$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_post_packaged:
	rm -f $(omap35x-graphics-sdk_PKG_INSTALL_DIR)/lib/modules/*/modules.*
	rm -f $(omap35x-graphics-sdk_PKG_INSTALL_DIR)/lib/modules/*/source
	$(call CREATE_PACKAGE, omap35x-graphics-sdk,$(omap35x-graphics-sdk_PKG_INSTALL_DIR),$(omap35x-graphics-sdk_PKG_NAME),$(omap35x-graphics-sdk_VERSION),$(omap35x-graphics-sdk_BUILDNUM),$(omap35x-graphics-sdk_RUNTIME_DEPENDS))
	@rm -rf $(omap35x-graphics-sdk_PKG_INSTALL_DIR)
	@touch $@


# Since it is an external directory, (dist)clean must be specially handled
omap35x-graphics-sdk-distclean: omap35x-graphics-sdk-clean

$(BUILD_DIR)/omap35x-graphics-sdk-$(omap35x-graphics-sdk_VERSION)/.stamp_cleaned:
	$(call PRINT_INFO,cleaning omap35x-graphics-sdk $(omap35x-graphics-sdk_VERSION))
	-cd $(omap35x-graphics-sdk_INSTALL_DIR)/GFX_Linux_KM && \
		ARCH=$(TSWO_KERNEL_ARCH) \
		$(omap35x-graphics-sdk_MAKE_CMD) clean \
		KERNELDIR=$(kernel_WORKINGDIR)
	-for demo in $(omap35x-graphics-sdk_DEMO_DIRS)/OGLES*/Build/LinuxGeneric; do \
	  PLATFORM=LinuxOMAP3 \
	  make -C $${demo} $(omap35x-graphics-sdk_DEMO_TYPE) clean ; \
	done
	-cd $(omap35x-graphics-sdk_DIR) && \
		rm -f .stamp_{*built,*rfs_installed,*host_installed,*packaged}

# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_omap35x-graphics-sdk))
SOFTWARE+=omap35x-graphics-sdk
endif


# vim:set noexpandtab filetype=make: 
