# Copyright (C) 2007-2010 Timesys Corporation
# qt-extended rules

qt-extended_BUILDDIR=$(qt-extended_DIR)/qt-extended-$(qt-extended_VERSION)-build
qt-extended_DEVICEDIR=$(qt-extended_DDIR)/devices/$(TSWO_BOARD)
qt-extended_SPECSDIR=$(qt-extended_DEVICEDIR)/mkspecs/qws/linux-$(TSWO_ARCH)-g++

qt-extended_MAKE_CMD=$(qt-extended_BUILDDIR)/bin/qbuild

$(eval $(call COMMON_SETUP,qt-extended))

# Fetch config file
$(qt-extended_SRC_DL_DIR)/qt-extended_config:
	$(call PRINT_INFO,fetching qt-extended config)
	$(call FETCH_REMOTE,$(qt-extended_SRC_DL_DIR),$(TSWO_qt-extended_CONFIG))
	cp -f $(qt-extended_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_qt-extended_CONFIG))) $@

# Fetch default buttons
$(qt-extended_SRC_DL_DIR)/qt-extended_defaultbuttons:
	$(call PRINT_INFO,fetching qt-extended defaultbuttons file)
	$(call FETCH_REMOTE,$(qt-extended_SRC_DL_DIR),$(TSWO_qt-extended_DEFAULTBUTTONS))
	cp -f $(qt-extended_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_qt-extended_DEFAULTBUTTONS))) $@

# Fetch qmake config
$(qt-extended_SRC_DL_DIR)/qt-extended_qmake_config:
	$(call PRINT_INFO,fetching qt-extended qmake config)
	$(call FETCH_REMOTE,$(qt-extended_SRC_DL_DIR),$(TSWO_qt-extended_QMAKE_CONFIG))
	cp -f $(qt-extended_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_qt-extended_QMAKE_CONFIG))) $@

# Fetch platdefs
$(qt-extended_SRC_DL_DIR)/qt-extended_platdefs:
	$(call PRINT_INFO,fetching qt-extended platform definitions)
	$(call FETCH_REMOTE,$(qt-extended_SRC_DL_DIR),$(TSWO_qt-extended_PLATDEFS))
	cp -f $(qt-extended_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_qt-extended_PLATDEFS))) $@

qt-extended-fetch: $(qt-extended_SRC_DL_DIR)/qt-extended_config $(qt-extended_SRC_DL_DIR)/qt-extended_defaultbuttons $(qt-extended_SRC_DL_DIR)/qt-extended_qmake_config $(qt-extended_SRC_DL_DIR)/qt-extended_platdefs


# Create device tree and build directory.
$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_pre_configured:
	mkdir -p $(qt-extended_BUILDDIR)
	mkdir -p $(qt-extended_DEVICEDIR)/etc
	mkdir -p $(qt-extended_SPECSDIR)
	cp -f $(qt-extended_SRC_DL_DIR)/qt-extended_platdefs $(qt-extended_SPECSDIR)/qplatformdefs.h
	cp -f $(qt-extended_SRC_DL_DIR)/qt-extended_qmake_config $(qt-extended_SPECSDIR)/qmake.conf
	cp -f $(qt-extended_SRC_DL_DIR)/qt-extended_config $(qt-extended_DEVICEDIR)/configure
	cp -f $(qt-extended_SRC_DL_DIR)/qt-extended_defaultbuttons $(qt-extended_DEVICEDIR)/etc/defaultbuttons.conf
	@touch $@


$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_configured: $(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_pre_configured
	$(call PRINT_INFO,configuring qt-extended $(qt-extended_VERSION))
#	$(call CONFIG_UPDATE,$(qt-extended_DDIR))
	cd $(qt-extended_BUILDDIR) && rm -rf config.cache 2>/dev/null && \
		PATH=$(BUILD_PATH) \
		$(TARGET_BUILD_OPTIONS) \
        $(qt-extended_BUILD_OPTIONS) \
		$(qt-extended_DDIR)/configure \
                        -device $(TSWO_BOARD) \
                        -xplatform linux-$(TSWO_ARCH)-g++ \
                        -prefix $(TSWO_qt-extended_PREFIX) \
			-arch $(TSWO_KERNEL_ARCH) \
        	$(qt-extended_CONFIGURE_OPTIONS)
	@touch $@

$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_built:
	$(call PRINT_INFO,building qt-extended $(qt-extended_VERSION))
	cd $(qt-extended_BUILDDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_BUILD_OPTIONS) \
        $(qt-extended_BUILD_OPTIONS) \
		$(qt-extended_MAKE_CMD)
	@touch $@

.PHONY: qt-extended-qmake-%

qt-extended-qmake-%:
	$(call PRINT_INFO,creating qt-extended $(qt-extended_VERSION) image)
	cd $(qt-extended_BUILDDIR) && \
	        PATH=$(BUILD_PATH) \
                $(TARGET_BUILD_OPTIONS) \
        	$(qt-extended_BUILD_OPTIONS) \
                $(qt-extended_MAKE_CMD) $*

$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_post_built:
	$(call PRINT_INFO,creating qt-extended $(qt-extended_VERSION) image)
	cd $(qt-extended_BUILDDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_BUILD_OPTIONS) \
        $(qt-extended_BUILD_OPTIONS) \
		$(qt-extended_MAKE_CMD) image
	@touch $@

$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing mypackage $(mypackage_VERSION) to the RFS)
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)
	cd $(qt-extended_BUILDDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) cp -rf image $(TSWO_RFS_INSTALL_DIR)/$(TSWO_qt-extended_PREFIX)
	@touch $@

$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_packaged: $(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_pre_packaged
	mkdir -p $(qt-extended_PKG_INSTALL_DIR)$(TSWO_qt-extended_PREFIX)
	cd $(qt-extended_BUILDDIR) && \
		PATH=$(BUILD_PATH) \
		cp -rf image/* $(qt-extended_PKG_INSTALL_DIR)$(TSWO_qt-extended_PREFIX)
	@touch $@

$(BUILD_DIR)/qt-extended-$(qt-extended_VERSION)/.stamp_host_installed:
	@touch $@

# add to software list
ifeq (y,$(TSWO_SOFTWARE_qt-extended))
SOFTWARE+=qt-extended
endif

# vim:set noexpandtab filetype=make: 
