# Copyright (C) 2007-2010 Timesys Corporation
# gst-ti-plugin rules

# Define common macros for gst-ti-plugin from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,gst-ti-plugin))


# Board specific configuration
ifeq (y,$(TSWO_BOARD_dm365_evm))
gst-ti-plugin-patch: ti-dvsdk-dm365-host-install
ti-dvsdk_PLATFORM=dm365
ti-dvsdk_XDC_PLATFORM=ti.platforms.evmDM365
ti-dvsdk_DIR=$(ti-dvsdk-dm365_DDIR)
endif

ifeq (y,$(TSWO_BOARD_omap3_evm))
gst-ti-plugin-patch: ti-dvsdk-omap3-host-install
ti-dvsdk_PLATFORM=omap3530
ti-dvsdk_XDC_PLATFORM=ti.platforms.evm3530
ti-dvsdk_DIR=$(ti-dvsdk-omap3_DDIR)
endif

# TODO/Future
ifeq (y,$(TSWO_BOARD_dm6446_dvevm))
ti-dvsdk_XDC_PLATFORM=ti.platforms.evmDM6446
endif
ifeq (y,$(TSWO_BOARD_dm6467_dvevm))
ti-dvsdk_XDC_PLATFORM=ti.platforms.evmDM6467
endif
ifeq (y,$(TSWO_BOARD_dm355_evm))
ti-dvsdk_XDC_PLATFORM=ti.platforms.evmDM355
endif



# Parameters to override Rules.make that should be passed to every make invocation
gst-ti-plugin_MAKE_VARS = \
        PLATFORM=$(ti-dvsdk_PLATFORM) \
	DVSDK_INSTALL_DIR=$(ti-dvsdk_DIR) \
	XDC_PLATFORM=$(ti-dvsdk_XDC_PLATFORM) \
        CSTOOL_DIR=$(TSWO_HOST_INSTALL_DIR)/bin \
        CSTOOL_PREFIX=$(TARGET_CROSS_PREFIX) \
        MVTOOL_DIR=$(TSWO_HOST_INSTALL_DIR)/bin \
        MVTOOL_PREFIX=$(TARGET_CROSS_PREFIX) \
	CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- 

gst-ti-plugin_CONFIGURE_OPTIONS+=CPPFLAGS=-DPlatform_$(ti-dvsdk_PLATFORM)

$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_pre_configured:
	cp -f $(gst-ti-plugin_SRC_DL_DIR)/Makefile.factory $(gst-ti-plugin_DDIR)/Makefile.factory
	cd $(gst-ti-plugin_DDIR) && \
		./autogen.sh --noconfigure
	@touch $@

$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_built:
	$(call PRINT_INFO,building gst-ti-plugin $(gst-ti-plugin_VERSION))
	cd $(gst-ti-plugin_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
        $(gst-ti-plugin_BUILD_OPTIONS) \
		$(gst-ti-plugin_MAKE_CMD) -f Makefile.factory \
		$(gst-ti-plugin_MAKE_VARS)
	@touch $@

$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_rfs_installed: INSTALL_DIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_packaged: INSTALL_DIR=$(gst-ti-plugin_PKG_INSTALL_DIR)
$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_host_installed: INSTALL_DIR=$(TSWO_HOST_INSTALL_DIR)

$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_rfs_installed $(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_host_installed $(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_packaged:
	$(call PRINT_INFO,installing gst-ti-plugin $(gst-ti-plugin_VERSION))
	@mkdir -p $(INSTALL_DIR)
	cd $(gst-ti-plugin_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        	$(gst-ti-plugin_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(gst-ti-plugin_MAKE_CMD) -f Makefile.factory \
		$(gst-ti-plugin_MAKE_VARS) \
		DESTDIR=$(INSTALL_DIR) install
	@touch $@

$(BUILD_DIR)/gst-ti-plugin-$(gst-ti-plugin_VERSION)/.stamp_cleaned:
	$(call PRINT_INFO,cleaning gst-ti-plugin $(gst-ti-plugin_VERSION))
	-cd $(gst-ti-plugin_DDIR) && \
		$(gst-ti-plugin_MAKE_CMD) \
		$(gst-ti-plugin_MAKE_VARS) \
		clean
	-cd $(gst-ti-plugin_DIR) && \
		rm -f .stamp_{*built,*rfs_installed,*host_installed,*packaged}

# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_gst-ti-plugin))
SOFTWARE+=gst-ti-plugin
endif


# vim:set noexpandtab filetype=make: 
