# Copyright (C) 2007-2010 Timesys Corporation
# ti-dvsdk-dm365 rules

# Define common macros for ti-dvsdk-dm365 from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,ti-dvsdk-dm365))

# Parameters to override Rules.make that should be passed to every make invocation
ti-dvsdk-dm365_MAKE_VARS = \
	PLATFORM=dm365 \
	DVSDK_INSTALL_DIR=$(ti-dvsdk-dm365_DDIR) \
	CSTOOL_DIR=$(TSWO_HOST_INSTALL_DIR) \
	CSTOOL_PREFIX=$(TARGET_CROSS_PREFIX) \
	MVTOOL_DIR=$(TSWO_HOST_INSTALL_DIR) \
	MVTOOL_PREFIX=$(TARGET_CROSS_PREFIX) \
	TSWO_FULL_TARGET_NAME=$(TSWO_FULL_TARGET_NAME) \
	LINUXLIBS_INSTALL_DIR=/unLikeLY/FacTory/UNLikeLY \
	LINUXKERNEL_INSTALL_DIR=$(kernel_WORKINGDIR)

ifneq (,$(TSWO_ti-dvsdk-dm365_CODEGEN_INSTALL_DIR))
ti-dvsdk-dm365_MAKE_VARS += CODEGEN_INSTALL_DIR=$(TSWO_ti-dvsdk-dm365_CODEGEN_INSTALL_DIR)
endif

# dvsdk requires a built kernel directory
ti-dvsdk-dm365-configure: kernel-build

$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_configured:
	@if [ $(TSWO_ti-dvsdk-dm365_CODEGEN_INSTALL_DIR) ]; then \
	  if [ ! -d $(TSWO_ti-dvsdk-dm365_CODEGEN_INSTALL_DIR) ]; then \
	    echo 'CG6X CodeGen Tools not found at $(TSWO_ti-dvsdk-dm365_CODEGEN_INSTALL_DIR)'; \
	    echo 'You must download and install these tools from TI before building dvsdk'; \
	    exit 1; \
	  fi; \
	fi
	@touch $@

$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_built:
	$(call PRINT_INFO,building ti-dvsdk-dm365 $(ti-dvsdk-dm365_VERSION))
	cd $(ti-dvsdk-dm365_DDIR) && \
        	$(ti-dvsdk-dm365_BUILD_OPTIONS) \
		$(ti-dvsdk-dm365_MAKE_CMD) \
		$(ti-dvsdk-dm365_MAKE_VARS)
	@touch $@

$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_rfs_installed: INSTALL_DIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_packaged: INSTALL_DIR=$(ti-dvsdk-dm365_PKG_INSTALL_DIR)
$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_host_installed: INSTALL_DIR=$(TSWO_HOST_INSTALL_DIR)

$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_rfs_installed $(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_packaged:
	$(call PRINT_INFO,installing ti-dvsdk-dm365 $(ti-dvsdk-dm365_VERSION))
	cd $(ti-dvsdk-dm365_DDIR) && \
        	$(ti-dvsdk-dm365_BUILD_OPTIONS) \
		$(ti-dvsdk-dm365_MAKE_CMD) \
		$(ti-dvsdk-dm365_MAKE_VARS) \
		EXEC_DIR=$(INSTALL_DIR)/opt/dvsdk/$(TSWO_ti-dvsdk-dm365_PLATFORM) \
		install
	@touch $@

# no host install for now.
$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_host_installed:
	@touch $@

$(BUILD_DIR)/ti-dvsdk-dm365-$(ti-dvsdk-dm365_VERSION)/.stamp_cleaned:
	$(call PRINT_INFO,cleaning ti-dvsdk-dm365 $(ti-dvsdk-dm365_VERSION))
	-cd $(ti-dvsdk-dm365_DDIR) && \
        	$(ti-dvsdk-dm365_BUILD_OPTIONS) \
		$(ti-dvsdk-dm365_MAKE_CMD) \
		$(ti-dvsdk-dm365_MAKE_VARS) \
		clean
	-cd $(ti-dvsdk-dm365_DIR) && \
		rm -f .stamp_{*built,*rfs_installed,*host_installed,*packaged}

# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_ti-dvsdk-dm365))
SOFTWARE+=ti-dvsdk-dm365
endif


# vim:set noexpandtab filetype=make: 
