# Copyright (C) 2007-2010 Timesys Corporation
# libsyncml rules

# Define common macros for libsyncml from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,libsyncml))

libsyncml_OPTIONAL_DEPS=libsoup openobex bluez
libsyncml_OPTIONAL_DEPS_TARGETS=$(foreach pkg,$(libsyncml_OPTIONAL_DEPS), $(if $(TSWO_SOFTWARE_$(pkg)),$(pkg)-host-install,))
libsyncml-patch: $(libsyncml_OPTIONAL_DEPS_TARGETS)

libsyncml-patch: cmake-host-build

$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring libsyncml $(libsyncml_VERSION))
	mkdir -p $(libsyncml_DDIR)/target-build
	cd $(libsyncml_DDIR)/target-build && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
		$(CMAKE) \
        $(libsyncml_BUILD_OPTIONS) \
        	$(libsyncml_CONFIGURE_OPTIONS) \
		..
	@touch $@

$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_built:
	$(call PRINT_INFO,building libsyncml $(libsyncml_VERSION))
	cd $(libsyncml_DDIR)/target-build && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
        $(libsyncml_BUILD_OPTIONS) \
		$(libsyncml_MAKE_CMD)
	@touch $@

$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_host_installed: DESTDIR=$(TSWO_HOST_INSTALL_DIR)
$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_rfs_installed: DESTDIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_packaged: DESTDIR=$(libsyncml_PKG_INSTALL_DIR)
$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_host_installed $(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_rfs_installed $(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_packaged:
	$(call PRINT_INFO,installing libsyncml $(libsyncml_VERSION) to $(DESTDIR))
	@mkdir -p $(DESTDIR)
	cd $(libsyncml_DDIR)/target-build && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $(libsyncml_BUILD_OPTIONS) \
			$(FAKEROOT_CMD) $(libsyncml_MAKE_CMD) DESTDIR=$(DESTDIR) install
	@touch $@


$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_post_host_installed:
	rm -rf $(TSWO_HOST_INSTALL_DIR)/usr/bin/syncml-ds-tool
	@touch $@



# Standard targets are defined as stamp files which are mapped to frontend
# targets.  For example, libsyncml-configure maps to
# $(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_configured

# The following targets contain the commands for each step of the package
# build process.  In order to modify the commands for any step, uncomment
# the target and modify as required.  To discard the default commands for
# a particular target, uncomment and remove the body leaving only the
# target definition and the final @touch $@.

# libsyncml-fetch is a frontend for:
#
#$(libsyncml_SRC_DL_DIR)/$(libsyncml_SOURCE):
#	$(call PRINT_INFO,fetching libsyncml $(libsyncml_VERSION))
#	@mkdir -p $(@D) $(libsyncml_SRC_DL_DIR)
#	$(call FETCH_REMOTE,$(libsyncml_SRC_DL_DIR),$(libsyncml_SOURCE_URL))
#	$(foreach patch,$(libsyncml_PATCHES),$(call FETCH_REMOTE,$(libsyncml_SRC_DL_DIR),$(libsyncml_URL)/$(patch)))
#	$(foreach file,$(libsyncml_FILES),$(call FETCH_REMOTE,$(libsyncml_SRC_DL_DIR),$(libsyncml_URL)/$(file)))

# libsyncml-unpack is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_unpacked:
#	$(call PRINT_INFO,unpacking libsyncml $(libsyncml_VERSION))
#	@mkdir -p $(@D)
#	@$(INFLATE$(suffix $(libsyncml_SOURCE))) $(libsyncml_SRC_DL_DIR)/$(libsyncml_SOURCE) | \
#		$(TAR) -C $(@D) $(TSWO_TAR_OPTIONS) -
#	@touch $@

# libsyncml-patch is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_patched:
#	$(call PRINT_INFO,patching libsyncml $(libsyncml_VERSION))
#	$(foreach patch,$(libsyncml_PATCHES),$(call APPLY_PATCH,$(libsyncml_DDIR),$(libsyncml_SRC_DL_DIR)/$(patch)))
#	@touch $@


#libsyncml-configure is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_pre_configured:
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_configured:
#	$(call PRINT_INFO,configuring libsyncml $(libsyncml_VERSION))
#	$(call CONFIG_UPDATE,$(libsyncml_DDIR))
#	cd $(libsyncml_DDIR) && rm -rf config.cache 2>/dev/null && \
#		PATH=$(BUILD_PATH) \
#		$(TARGET_ALIASES) \
#		$(TARGET_BUILD_OPTIONS) \
#        $(libsyncml_BUILD_OPTIONS) \
#		./configure \
#			--target=$(TSWO_FULL_TARGET_NAME) \
#			--host=$(TSWO_FULL_TARGET_NAME) \
#			--build=$(TSWO_BUILD_NAME) \
#        	--prefix=/usr \
#        	--exec-prefix=/usr \
#			--bindir=/usr/bin \
#			--sbindir=/usr/sbin \
#			--libdir=/usr/lib \
#			--libexecdir=/usr/lib \
#			--sysconfdir=/etc \
#			--datadir=/usr/share \
#			--localstatedir=/var \
#			--mandir=/usr/share/man \
#			--infodir=/usr/share/info \
#			--includedir=/usr/include \
#			$(TARGET_CONFIGURE_OPTIONS) \
#        	$(libsyncml_CONFIGURE_OPTIONS)
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_post_configured:
#	@touch $@

# libsyncml-build is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_pre_built:
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_built:
#	$(call PRINT_INFO,building libsyncml $(libsyncml_VERSION))
#	cd $(libsyncml_DDIR) && \
#		PATH=$(BUILD_PATH) \
#		$(TARGET_ALIASES) \
#		$(TARGET_BUILD_OPTIONS) \
#        $(libsyncml_BUILD_OPTIONS) \
#		$(libsyncml_MAKE_CMD)
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_post_built:
#	@touch $@

# libsyncml-rfs-install is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_pre_rfs_installed:
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_rfs_installed:
#	$(call PRINT_INFO,installing libsyncml $(libsyncml_VERSION) to the RFS)
#	@mkdir -p $(TSWO_RFS_INSTALL_DIR)
#	cd $(libsyncml_DDIR) && \
#		PATH=$(BUILD_PATH) \
#		$(TARGET_ALIASES) \
#        $(libsyncml_BUILD_OPTIONS) \
#			$(FAKEROOT_CMD) $(libsyncml_MAKE_CMD) DESTDIR=$(TSWO_RFS_INSTALL_DIR) install
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_post_rfs_installed:
#	@touch $@

# libsyncml-host-install is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_pre_host_installed:
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_host_installed:
#	$(call PRINT_INFO,installing libsyncml $(libsyncml_VERSION) to host)
#	@mkdir -p $(TSWO_HOST_INSTALL_DIR)
#	cd $(libsyncml_DDIR) && \
#		PATH=$(BUILD_PATH) \
#		$(TARGET_ALIASES) \
#        $(libsyncml_BUILD_OPTIONS) \
#		$(FAKEROOT_CMD) $(libsyncml_MAKE_CMD) DESTDIR=$(TSWO_HOST_INSTALL_DIR) install
#	$(call FIX_LIBTOOL_ARCHIVES,$(TSWO_HOST_INSTALL_DIR))
#	$(call FIX_CONFIG_SCRIPTS,$(TSWO_HOST_INSTALL_DIR))
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_post_host_installed:
#	@touch $@

# libsyncml-package is a frontend for:
#
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_pre_packaged:
#	$(call PRINT_INFO,packaging libsyncml $(libsyncml_VERSION))
#	@mkdir -p $(libsyncml_PKG_INSTALL_DIR)
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_packaged:
#	cd $(libsyncml_DDIR) && \
#		PATH=$(BUILD_PATH) \
#		$(TARGET_ALIASES) \
#        $(libsyncml_BUILD_OPTIONS) \
#		$(FAKEROOT_CMD) $(libsyncml_MAKE_CMD) DESTDIR=$(libsyncml_PKG_INSTALL_DIR) install
#	@touch $@
#$(BUILD_DIR)/libsyncml-$(libsyncml_VERSION)/.stamp_post_packaged:
#	$(call CREATE_PACKAGE, libsyncml,$(libsyncml_PKG_INSTALL_DIR),$(libsyncml_PKG_NAME),$(libsyncml_VERSION),$(libsyncml_BUILDNUM),$(libsyncml_RUNTIME_DEPENDS))
#	@rm -rf $(libsyncml_PKG_INSTALL_DIR)
#	@touch $@


# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_libsyncml))
SOFTWARE+=libsyncml
endif


# vim:set noexpandtab filetype=make: 
