# Copyright (C) 2007-2010 Timesys Corporation
# termcap rules

# Define common macros for this termcap from include/common.mk
$(eval $(call COMMON_SETUP,termcap))

$(BUILD_DIR)/termcap-$(termcap_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring termcap)
	cd $(termcap_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_BUILD_OPTIONS) \
		$(termcap_BUILD_OPTIONS) \
		./configure \
			--target=$(TSWO_FULL_TARGET_NAME) \
			--host=$(TSWO_FULL_TARGET_NAME) \
			--build=$(TSWO_BUILD_NAME) \
        	--prefix=/usr \
			$(TARGET_CONFIGURE_OPTIONS) \
			$(termcap_CONFIGURE_OPTIONS)
	@touch $(@)

$(BUILD_DIR)/termcap-$(termcap_VERSION)/.stamp_packaged:
	mkdir -p $(termcap_PKG_INSTALL_DIR)/usr/include
	mkdir -p $(termcap_PKG_INSTALL_DIR)/etc
	cd $(termcap_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(MAKE) oldincludedir= prefix=$(termcap_PKG_INSTALL_DIR)/usr install
	cd $(termcap_DDIR) && \
		cp -f termcap.h $(termcap_PKG_INSTALL_DIR)/usr/include/termcap.h && \
		cp -f termcap.src $(termcap_PKG_INSTALL_DIR)/etc/termcap
	@touch $(@)

$(BUILD_DIR)/termcap-$(termcap_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing termcap to the host)
	cd $(termcap_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(MAKE) oldincludedir= prefix=$(TSWO_HOST_INSTALL_DIR) install
	cd $(termcap_DDIR) && \
		cp -f termcap.h $(TSWO_HOST_INSTALL_DIR)/include/termcap.h
	@touch $@

$(BUILD_DIR)/termcap-$(termcap_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing termcap to the rfs)
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/etc
	cd $(termcap_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(MAKE) prefix=$(TSWO_RFS_INSTALL_DIR)/usr install
	cd $(termcap_DDIR) && \
		cp -f termcap.h $(TSWO_RFS_INSTALL_DIR)/usr/include/termcap.h && \
		cp -f termcap.src $(TSWO_RFS_INSTALL_DIR)/etc/termcap
	@touch $@

TERMCAP_HOST_INSTALL_DIR=$(BUILD_DIR)/termcap-$(termcap_VERSION)/termcap-host-install
termcap-host-build: termcap-fetch $(BUILD_DIR)/termcap-$(termcap_VERSION)/.stamp_host_built
$(BUILD_DIR)/termcap-$(termcap_VERSION)/.stamp_host_built:
	$(call PRINT_INFO,building termcap host copy)
	mkdir -p $(@D)/termcap-host-build
	$(INFLATE$(suffix $(termcap_SOURCE))) $(termcap_SRC_DL_DIR)/$(termcap_SOURCE) | \
		$(TAR) -C $(@D)/termcap-host-build $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(termcap_PATCHES),$(call APPLY_PATCH,$(@D)/termcap-host-build/$(termcap_WORKINGDIR),$(termcap_SRC_DL_DIR)/$(patch)))
	cd $(@D)/termcap-host-build/$(termcap_WORKINGDIR) && \
		PATH=$(BUILD_PATH) \
		./configure \
        	--prefix=$(TERMCAP_HOST_INSTALL_DIR)
	cd $(@D)/termcap-host-build/$(termcap_WORKINGDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(MAKE) install
	@touch $@

# add to software list
ifeq (y,$(TSWO_SOFTWARE_termcap))
SOFTWARE+=termcap
endif


# vim:set noexpandtab: 
