# Copyright (C) 2007-2010 Timesys Corporation
# util-linux rules

# Define common macros for this util-linux from include/common.mk
$(eval $(call COMMON_SETUP,util-linux))

ifeq (y,$(TSWO_LIBC_UCLIBC))
util-linux_CONFIGURE_OPTIONS+=--enable-nls
util-linux_BUILD_OPTIONS+=LDFLAGS="-lintl"
endif

# e2fsprogs also provides libuuid and libblkid and
# should be installed first if selected
ifeq (y,$(TSWO_SOFTWARE_e2fsprogs))
util-linux-rfs-install: e2fsprogs-rfs-install
util-linux-host-install: e2fsprogs-host-install
endif

ifeq (y,$(TSWO_SOFTWARE_ncurses))
util-linux-patch: ncurses-host-install
else
util-linux_CONFIGURE_OPTIONS+=--without-ncurses
endif

$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_post_host_installed:
	rm -f $(TSWO_HOST_INSTALL_DIR)/bin/{cal,wall,setterm,hexdump,namei,ipcmk,setsid,ipcrm,chrt,scriptreplay,ionice,getopt,mount,chkdupexe,taskset,linux64,line,more,pg,col,uuidgen,rename,linux32,cytune,lscpu,look,ul,logger,column,ddate,colrm,flock,rev,setarch,ipcs,dmesg,umount,mcookie,tailf,script,colcrt,whereis,isosize,renice,fallocate,unshare}
	rm -f $(TSWO_HOST_INSTALL_DIR)/sbin/{fsck.minix,losetup,uuidd,rtcwake,ctrlaltdel,pivot_root,mkfs.minix,fsck,swapon,hwclock,sfdisk,readprofile,fdformat,mkswap,agetty,cfdisk,tunelp,fsck.cramfs,mkfs.cramfs,mkfs,ldattach,swapoff,fdisk,blockdev,blkid,findfs,mkfs.bfs,switch_root,wipefs}
	$(SED) -i -re 's,^exec_prefix=.*,exec_prefix=$(TSWO_HOST_INSTALL_DIR)/usr,' $(TSWO_HOST_INSTALL_DIR)/lib/pkgconfig/{uuid.pc,blkid.pc}
	-$(SED) -i -re 's/\s\/lib\/libuuid\.la//' $(TSWO_HOST_INSTALL_DIR)/lib/libblkid.la
	@touch $@


$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring util-linux $(util-linux_VERSION))
	$(call CONFIG_UPDATE,$(util-linux_DDIR))
	cd $(util-linux_DDIR) && \
		find . -name ltmain.sh -exec $(SED) -i.orig -re '/add_dir="-L\$$libdir"/d' {} \;
	cd $(util-linux_DDIR) && rm -rf config.cache 2>/dev/null && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
        $(util-linux_BUILD_OPTIONS) \
		./configure \
			--target=$(TSWO_FULL_TARGET_NAME) \
			--host=$(TSWO_FULL_TARGET_NAME) \
			--build=$(TSWO_BUILD_NAME) \
        	--prefix=/ \
        	--exec-prefix= \
			--bindir=/bin \
			--sbindir=/sbin \
			--libdir=/lib \
			--libexecdir=/lib \
			--sysconfdir=/etc \
			--datadir=/usr/share \
			--localstatedir=/var \
			--mandir=/usr/share/man \
			--infodir=/usr/share/info \
			--includedir=/usr/include \
			$(TARGET_CONFIGURE_OPTIONS) \
        	$(util-linux_CONFIGURE_OPTIONS)
	@touch $@

$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_mk_rundir_rfs_installed: DESTDIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_mk_rundir_packaged: DESTDIR=$(util-linux_PKG_INSTALL_DIR)
$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_post_rfs_installed: $(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_mk_rundir_rfs_installed
$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_post_packaged: $(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_mk_rundir_packaged
$(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_mk_rundir_rfs_installed $(BUILD_DIR)/util-linux-$(util-linux_VERSION)/.stamp_mk_rundir_packaged:
	mkdir -p $(DESTDIR)/var/run/uuidd
	mkdir -p $(DESTDIR)/usr/lib/pkgconfig
	if [ -d $(DESTDIR)/lib/pkgconfig ]; then \
		mv -f $(DESTDIR)/lib/pkgconfig/* $(DESTDIR)/usr/lib/pkgconfig/; \
		rmdir $(DESTDIR)/lib/pkgconfig; \
	fi
	@touch $(@)


# add to software list
ifeq (y,$(TSWO_SOFTWARE_util-linux))
SOFTWARE+=util-linux
endif


# vim:set noexpandtab: 
