# Copyright (C) 2007-2010 Timesys Corporation
# cups rules

# be set and overriden from the configuration interface. Setting them
# here is helpful when testing a new package or bypassing the configuration
# interface altogether.

# Define common macros for cups from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,cups))

cups_OPTIONAL_DEPS=acl dbus libjpeg libpng
cups_OPTIONAL_DEPS_TARGETS=$(foreach pkg,$(cups_OPTIONAL_DEPS), $(if $(TSWO_SOFTWARE_$(pkg)),$(pkg)-host-install,))
cups-patch: $(cups_OPTIONAL_DEPS_TARGETS)

CUPS_CPPFLAGS=
CUPS_LDFLAGS=

ifeq (y,$(TSWO_SOFTWARE_pam))
cups-patch: pam-host-install
else
cups_CONFIGURE_OPTIONS+=--disable-pam
endif

ifeq (y,$(TSWO_SOFTWARE_openldap))
cups-patch: openldap-host-install
else
cups_CONFIGURE_OPTIONS+=--disable-ldap
endif

ifeq (y,$(TSWO_SOFTWARE_libgssapi))
cups-patch: libgssapi-host-install
ifeq (y,$(TSWO_SOFTWARE_krb5))
cups-patch: krb5-host-install
CUPS_CPPFLAGS+="-I$(TSWO_HOST_INSTALL_DIR)/include/gssglue"
CUPS_LDFLAGS+="-L$(TSWO_HOST_INSTALL_DIR)/lib"
else
cups_CONFIGURE_OPTIONS+=ac_cv_path_KRB5CONFIG=
endif
else
cups_CONFIGURE_OPTIONS+=--disable-gssapi
endif

ifeq (y,$(TSWO_SOFTWARE_openslp))
cups-patch: openslp-host-install
else
cups_CONFIGURE_OPTIONS+=--disable-slp
endif

ifeq (y,$(TSWO_SOFTWARE_openssl))
cups-patch: openssl-host-install
else
cups_CONFIGURE_OPTIONS+=--disable-ssl
endif

ifeq (y,$(TSWO_SOFTWARE_gnutls))
cups-patch: gnutls-host-install
cups_CONFIGURE_OPTIONS+=--enable-tls
else
cups_CONFIGURE_OPTIONS+=--enable-tls=no
endif

ifneq (,$(CUPS_CPPFLAGS))
cups_CONFIGURE_OPTIONS+=CPPFLAGS="$(CUPS_CPPFLAGS)"
endif
ifneq (,$(CUPS_LDFLAGS))
cups_CONFIGURE_OPTIONS+=LDFLAGS="$(CUPS_LDFLAGS)"
endif

$(BUILD_DIR)/cups-$(cups_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing cups $(cups_VERSION) to the RFS)
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)
	cd $(cups_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $(cups_BUILD_OPTIONS) \
			$(FAKEROOT_CMD) $(cups_MAKE_CMD) DSTROOT=$(TSWO_RFS_INSTALL_DIR) install
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/etc/init.d
	cp -f $(cups_SRC_DL_DIR)/S85-cupsd $(TSWO_RFS_INSTALL_DIR)/etc/init.d/
	chmod +x $(TSWO_RFS_INSTALL_DIR)/etc/init.d/S85-cupsd
	-rm -rf $(TSWO_RFS_INSTALL_DIR)/etc/rc*/*cup*
	-rm -rf $(TSWO_RFS_INSTALL_DIR)/etc/init.d/cups
	-rmdir $(TSWO_RFS_INSTALL_DIR)/etc/rc[0123456].d
	@touch $@

$(BUILD_DIR)/cups-$(cups_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing cups $(cups_VERSION) to host)
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)
	cd $(cups_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $(cups_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(cups_MAKE_CMD) DSTROOT=$(TSWO_HOST_INSTALL_DIR) install
	$(call FIX_LIBTOOL_ARCHIVES,$(TSWO_HOST_INSTALL_DIR))
	$(call FIX_CONFIG_SCRIPTS,$(TSWO_HOST_INSTALL_DIR))
	rm -rf $(TSWO_HOST_INSTALL_DIR)/usr/sbin/{lpadmin,lpc,cupsreject,cupsaccept,lpinfo,lpmove,cupsdisable,cupsfilter,cupsd,accept,cupsenable,cupsctl,cupsaddsmb,reject}
	rm -rf $(TSWO_HOST_INSTALL_DIR)/usr/bin/{lpoptions,lprm,lppasswd,lpstat,lpr,cancel,cupstestdsc,lp,ppdhtml,ppdc,lpq,ppdmerge,ppdpo,cupstestppd,ppdi}
	@touch $@

$(BUILD_DIR)/cups-$(cups_VERSION)/.stamp_packaged:
	cd $(cups_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $(cups_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(cups_MAKE_CMD) DSTROOT=$(cups_PKG_INSTALL_DIR) install
	mkdir -p $(cups_PKG_INSTALL_DIR)/etc/init.d
	cp -f $(cups_SRC_DL_DIR)/S85-cupsd $(cups_PKG_INSTALL_DIR)/etc/init.d/
	chmod +x $(cups_PKG_INSTALL_DIR)/etc/init.d/S85-cupsd
	-rm -rf $(cups_PKG_INSTALL_DIR)/etc/rc*/*cup*
	-rm -rf $(cups_PKG_INSTALL_DIR)/etc/init.d/cups
	-rmdir $(cups_PKG_INSTALL_DIR)/etc/rc[0123456].d
	@touch $@


# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_cups))
SOFTWARE+=cups
endif


# vim:set noexpandtab filetype=make: 
