# Copyright (C) 2007-2010 Timesys Corporation
# ghostscript rules

# Define common macros for ghostscript from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,ghostscript))

ghostscript_OPTIONAL_DEPS=libpng cups libXt libXext
ghostscript_OPTIONAL_DEPS_TARGETS=$(foreach pkg,$(ghostscript_OPTIONAL_DEPS), $(if $(TSWO_SOFTWARE_$(pkg)),$(pkg)-host-install,))
ghostscript-patch: $(ghostscript_OPTIONAL_DEPS_TARGETS)

ifneq (y,$(TSWO_SOFTWARE_cups))
ghostscript_CONFIGURE_OPTIONS+=--disable-cups
endif

$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_post_host_installed:
	rm -rf $(TSWO_HOST_INSTALL_DIR)/usr/bin/{ps2pdf13,dumphint,pdfopt,printafm,wftopfa,ps2pdf12,ps2epsi,ps2pdf,lprsetup.sh,pv.sh,pf2afm,gslj,bdftops,gsnd,gsdj,fixmswrd.pl,ps2pdf14,ps2ascii,ps2pdfwr,ps2ps,pfbtopfa,pdf2dsc,dvipdf,unix-lpr.sh,pdf2ps,eps2eps,ps2ps2,gsbj,gsdj500,font2c,gs,gslp}
	@touch $@

$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_pre_built:
	cd $(ghostscript_DDIR) && \
		mkdir -p obj && \
		make obj/echogs obj/genconf obj/genarch obj/mkromfs  CC=gcc CFLAGS= FONTCONFIG_CFLAGS=-I/usr/include EXTRALIBS='-ldl -lm -lstdc++ -lfontconfig'
	@touch $@

$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_built:
	$(call PRINT_INFO,building ghostscript $(ghostscript_VERSION))
	cd $(ghostscript_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
		$(ghostscript_MAKE_CMD) \
        $(ghostscript_BUILD_OPTIONS) so gs.a
	@touch $@

$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_rfs_installed: DESTDIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_host_installed: DESTDIR=$(TSWO_HOST_INSTALL_DIR)
$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_packaged: DESTDIR=$(ghostscript_PKG_INSTALL_DIR)
$(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_rfs_installed $(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_host_installed $(BUILD_DIR)/ghostscript-$(ghostscript_VERSION)/.stamp_packaged:
	$(call PRINT_INFO,installing ghostscript $(ghostscript_VERSION) to the $(DESTDIR))
	@mkdir -p $(DESTDIR)/usr/lib
	cd $(ghostscript_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
			$(FAKEROOT_CMD) $(ghostscript_MAKE_CMD) DESTDIR=$(DESTDIR) soinstall \
        $(ghostscript_BUILD_OPTIONS)
	-cp -rf $(ghostscript_DDIR)/gs.a $(DESTDIR)/usr/lib/libgs.a
	@touch $@


# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_ghostscript))
SOFTWARE+=ghostscript
endif


# vim:set noexpandtab filetype=make: 
