# Copyright (C) 2007-2009 Timesys Corporation
# gdb rules

# deps for target gdb
gdb-configure: gmp-host-install ncurses-host-install
ifeq (y,$(TSWO_LIBC_UCLIBC))
gdb-configure: gettext-host-install
endif

# Define common macros for this gdb from include/common.mk
$(eval $(call COMMON_SETUP,gdb))

# XXX need this to reset CFLAGS for sim build
gdb_BUILD_OPTIONS=CFLAGS=

# unnecessary
#ifeq ($(LIBC),uClibc)
#gdb_BUILD_OPTIONS+=LDFLAGS=-lintl
#endif

# Host GDB
GDB_HOST_BUILD_DIR=$(BUILD_DIR)/gdb-$(gdb_VERSION)/gdb-host-build

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_toolchain_unpacked:
	$(call PRINT_INFO,unpacking gdb $(gdb_VERSION) for host build)
	@mkdir -p $(GDB_HOST_BUILD_DIR)
	@$(INFLATE$(suffix $(gdb_SOURCE))) $(gdb_SRC_DL_DIR)/$(gdb_SOURCE) | \
		$(TAR) -C $(GDB_HOST_BUILD_DIR) $(TSWO_TAR_OPTIONS) -
	@mv -f $(GDB_HOST_BUILD_DIR)/gdb-$(gdb_VERSION) $(GDB_HOST_BUILD_DIR)/gdb-$(gdb_VERSION)_unpacked
	@mv -f $(GDB_HOST_BUILD_DIR)/gdb-$(gdb_VERSION)_unpacked/* $(GDB_HOST_BUILD_DIR)/
	@rm -rf $(GDB_HOST_BUILD_DIR)/gdb-$(gdb_VERSION)_unpacked
	$(call PRINT_INFO,patching gdb $(gdb_VERSION) for host build)
	$(foreach patch,$(gdb_PATCHES),$(call APPLY_PATCH,$(GDB_HOST_BUILD_DIR),$(gdb_SRC_DL_DIR)/$(patch)))
	@touch $@

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_toolchain_built:
	$(call PRINT_INFO,configuring gdb $(gdb_VERSION) for the host)
	cd $(GDB_HOST_BUILD_DIR) && \
		$(HOST_BUILD_OPTIONS) \
		LDFLAGS="-static"\
		./configure \
			--prefix=$(TSWO_HOST_INSTALL_DIR) \
			--build=$(TSWO_BUILD_NAME) \
			--host=$(TSWO_HOST_NAME) \
			--target=$(TSWO_FULL_TARGET_NAME) \
                        --with-sysroot=$(TSWO_HOST_INSTALL_DIR)/. \
			$(HOST_CONFIGURE_OPTIONS) \
			$(gdb_CONFIGURE_OPTIONS)
	cd $(GDB_HOST_BUILD_DIR) && \
		$(HOST_BUILD_OPTIONS) \
		$(MAKE)
	@touch $@

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_installed:
	@touch $@

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_toolchain_installed:
	$(call PRINT_INFO,installing gdb to the host)
	cd $(GDB_HOST_BUILD_DIR) && \
		$(MAKE) install
	rm -f $(TSWO_HOST_INSTALL_DIR)/lib/libiberty.a
	@touch $@

gdb-toolchain-fetch: gdb-fetch
gdb-toolchain-patch: gdb-toolchain-fetch gdb-patch
gdb-toolchain-unpack: gdb-toolchain-patch $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_toolchain_unpacked
gdb-toolchain-configure: gdb-toolchain-unpack gmp-toolchain-host-install
gdb-toolchain-build: gdb-toolchain-configure $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_toolchain_built
gdb-toolchain-host-install: gdb-toolchain-build $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_host_toolchain_installed
gdb-toolchain-rfs-install:
gdb-toolchain-package:
gdbserver-distclean:

#
# target gdbserver
#
GDBSERVER_PKG_INSTALL_DIR=$(PACKAGE_DIR)/gdbserver_install
GDBSERVER_BUILDNUM=1
GDBSERVER_PKG_NAME=$(PACKAGE_DIR)/gdbserver-$(gdb_VERSION)-$(TSWO_FULL_TARGET_NAME)-$(GDBSERVER_BUILDNUM).tgz

gdbserver-fetch: gdb-fetch
gdbserver-unpack: gdb-unpack
gdbserver-patch: gdb-patch

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_configured:
	$(call PRINT_INFO,configuring gdbserver)
	-@cd $(gdb_DDIR)/gdb/gdbserver && \
		$(MAKE) distclean &>/dev/null
	cd $(gdb_DDIR)/gdb/gdbserver && rm -f config.cache 2>/dev/null && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		./configure \
			--target=$(TSWO_FULL_TARGET_NAME) \
			--host=$(TSWO_FULL_TARGET_NAME) \
			--build=$(TSWO_BUILD_NAME) \
        	--prefix=/usr \
        	--exec-prefix=/usr \
			--bindir=/usr/bin \
			--sbindir=/usr/sbin \
			--libdir=/usr/lib \
			--libexecdir=/usr/lib \
			--sysconfdir=/etc \
			--datadir=/usr/share \
			--localstatedir=/var \
			--mandir=/usr/share/man \
			--infodir=/usr/share/info \
			--includedir=/usr/include
	@touch $@
gdbserver-configure: gdbserver-patch $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_configured

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_built:
	$(call PRINT_INFO,building gdbserver)
	cd $(gdb_DDIR)/gdb/gdbserver && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(MAKE)
	@touch $@
gdbserver-build: gdbserver-configure $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_built

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_rfs_installed:
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/usr/bin/
	$(call PRINT_INFO,installing gdbserver to the RFS)
	cp -f $(gdb_DDIR)/gdb/gdbserver/gdbserver $(TSWO_RFS_INSTALL_DIR)/usr/bin/
	@touch $@
gdbserver-rfs-install: gdbserver-build $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_rfs_installed

$(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_package:
	$(call PRINT_INFO,creating gdbserver package)
	mkdir -p $(GDBSERVER_PKG_INSTALL_DIR)/usr/bin
	mkdir -p $(GDBSERVER_PKG_INSTALL_DIR)/usr/share/man/man1
	cp -f $(gdb_DDIR)/gdb/gdbserver/gdbserver $(GDBSERVER_PKG_INSTALL_DIR)/usr/bin/
	cp -f $(gdb_DDIR)/gdb/gdbserver/gdbserver.1 $(GDBSERVER_PKG_INSTALL_DIR)/usr/share/man/man1/gdbserver.1
	$(call CREATE_PACKAGE, gdbserver,$(GDBSERVER_PKG_INSTALL_DIR),$(GDBSERVER_PKG_NAME),$(gdb_VERSION),$(gdb_BUILDNUM),$(gdb_RUNTIME_DEPENDS))
	rm -rf $(GDBSERVER_PKG_INSTALL_DIR)
	@touch $@
gdbserver-package: gdbserver-build $(BUILD_DIR)/gdb-$(gdb_VERSION)/.stamp_gdbserver_package
gdbserver-distclean:

# add to toolchain list
ifeq (y,$(TSWO_GDB))
HOST_UTILITIES+=gdb-toolchain
endif

ifeq (y,$(TSWO_SOFTWARE_gdbserver))
SOFTWARE+=gdbserver
endif

ifeq (y,$(strip $(TSWO_INSTALL_TOOLCHAIN_TO_TARGET)))
ifeq (y,$(TSWO_GDB))
ifneq (y, $(strip $(TSWO_sh4)))
SOFTWARE+=gdb
endif
endif
endif

# vim:set noexpandtab: 
