# Copyright (C) 2007-2009 Timesys Corporation
# pkgconfig rules

# Define common macros for this pkgconfig from include/common.mk
$(eval $(call COMMON_SETUP,pkgconfig))

# build it for the host
pkgconfig-toolchain-fetch: pkgconfig-fetch
pkgconfig-toolchain-unpack: pkgconfig-toolchain-fetch $(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_unpacked
pkgconfig-toolchain-configure: pkgconfig-toolchain-unpack $(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_configured
pkgconfig-toolchain-build: pkgconfig-toolchain-configure $(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_built
pkgconfig-toolchain-host-install: pkgconfig-toolchain-build $(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_host_installed
pkgconfig_HOST_DIR=$(pkgconfig_DIR)/pkgconfig-host-build/$(pkgconfig_WORKINGDIR)

$(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_unpacked:
	mkdir -p $(@D)/pkgconfig-host-build
	$(INFLATE$(suffix $(pkgconfig_SOURCE))) $(pkgconfig_SRC_DL_DIR)/$(pkgconfig_SOURCE) | \
		$(TAR) -C $(@D)/pkgconfig-host-build $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(pkgconfig_PATCHES),$(call APPLY_PATCH,$(@D)/pkgconfig-host-build/$(pkgconfig_WORKINGDIR),$(pkgconfig_SRC_DL_DIR)/$(patch)))
	$(call CONFIG_UPDATE,$(pkgconfig_HOST_DIR))
	@touch $@

$(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_configured:
	$(call PRINT_INFO,configuring pkgconfig $(pkgconfig_VERSION) for the host)
	cd $(pkgconfig_HOST_DIR) && \
		$(HOST_BUILD_OPTIONS) \
		./configure \
        	--prefix=$(TSWO_HOST_INSTALL_DIR) \
        	--exec-prefix=/usr \
        	--sysconfdir=/etc \
			--bindir=/usr/bin \
			--sbindir=/usr/sbin \
			--libdir=/lib \
			--libexecdir=/usr/lib \
			--sysconfdir=/etc \
			--datadir=/usr/share \
			--localstatedir=/var \
			--mandir=/usr/share/man \
			--infodir=/usr/share/info \
			--includedir=/usr/include \
			$(HOST_CONFIGURE_OPTIONS) \
				CC=$(HOSTCC)
	@touch $@

$(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_built:
	$(call PRINT_INFO,building pkgconfig $(pkgconfig_VERSION))
	cd $(pkgconfig_HOST_DIR) && \
		PATH=$(BUILD_PATH) \
		$(pkgconfig_MAKE_CMD) \
		$(HOST_BUILD_OPTIONS) \
				CC=$(HOSTCC)
	@touch $@

PKGCONFIG_HOST_BIN=$(TSWO_HOST_INSTALL_DIR)/usr/bin/pkg-config

$(BUILD_DIR)/pkgconfig-$(pkgconfig_VERSION)/.stamp_toolchain_host_installed:
	$(call PRINT_INFO,installing pkgconfig $(pkgconfig_VERSION) to the host)
	cd $(pkgconfig_HOST_DIR) && \
		$(pkgconfig_MAKE_CMD) DESTDIR=$(TSWO_HOST_INSTALL_DIR) install
	@mv $(PKGCONFIG_HOST_BIN) $(PKGCONFIG_HOST_BIN).real
	@echo '#!/bin/sh' \
		> $(PKGCONFIG_HOST_BIN)
	@echo 'CMD=$$0' \
		>> $(PKGCONFIG_HOST_BIN)
	@echo 'BASE=$$(dirname $$CMD)' \
		>> $(PKGCONFIG_HOST_BIN)
	@echo 'PKG_CONFIG_LIBDIR=$$BASE/../lib' \
		>> $(PKGCONFIG_HOST_BIN)
	@echo 'PKG_CONFIG_PATH=$$BASE/../lib/pkgconfig:$$BASE/../usr/lib/pkgconfig:$$BASE/../share/pkgconfig:$$BASE/../usr/share/pkgconfig' \
		>> $(PKGCONFIG_HOST_BIN)
	@echo 'export PKG_CONFIG_LIBDIR PKG_CONFIG_PATH' \
		>> $(PKGCONFIG_HOST_BIN)
	@echo '$${CMD}.real $$*' \
		>> $(PKGCONFIG_HOST_BIN)
	@chmod +x $(PKGCONFIG_HOST_BIN) $(PKGCONFIG_HOST_BIN).real
	@cd $(TSWO_HOST_INSTALL_DIR)/usr/bin && cp pkg-config.real $(TARGET_CROSS_PREFIX)pkg-config.real
	@cd $(TSWO_HOST_INSTALL_DIR)/usr/bin && cp pkg-config $(TARGET_CROSS_PREFIX)pkg-config
	@touch $@


# add to software list
ifeq (y,$(TSWO_HOSTTOOL_pkgconfig))
HOST_UTILITIES+=pkgconfig-toolchain
endif
ifeq (y,$(TSWO_SOFTWARE_pkgconfig))
SOFTWARE+=pkgconfig
endif


# vim:set noexpandtab: 
